@@ -9,7 +9,8 @@
 //  Module:         Multithreaded AFF (AAFF = Advanced AFF)
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -50,6 +51,7 @@
 #define AFF_SEGARG_U64   2  // Used as argument for segments that contain a 64 bit unsigned in the data field
 
 #define AFF_HEADER                    "AFF10\r\n"
+#define AFF_HEADER_LEN                7
 #define AFF_SEGMENT_HEADER_MAGIC      "AFF"
 #define AFF_SEGMENT_FOOTER_MAGIC      "ATT"
 #define AFF_BADSECTOR_HEADER          "BAD SECTOR"
@@ -80,7 +82,7 @@ typedef struct
    unsigned int NameLen;
    unsigned int DataLen;
    unsigned int Argument;          // Named "flags" in original aff source, named "arg" in afinfo output.
-   char         Name[0];
+   char         Name[];
 } __attribute__ ((packed)) t_AffSegmentHeader;
 
 // Between header and footer lie the segment name and the data
@@ -96,6 +98,10 @@ typedef struct
 //  Aaff definitions
 // ------------------
 
+#pragma GCC diagnostic push
+#ifdef Q_CREATOR_RUN
+#pragma GCC diagnostic ignored "-Wgnu-variable-sized-type-not-at-end"
+#endif
 typedef struct _t_Aaff
 {
    FILE               *pFile;
@@ -105,20 +111,20 @@ typedef struct _t_Aaff
    t_HashContextMD5     HashContextMD5; // For image file MD5 calculation during verification
    QString            *pFilename;
 
-
-   t_AffSegmentHeader   SegmentHeader;  // Optimisation: This header and this footer only need to be
-   t_AffSegmentFooter   SegmentFooter;  // allocated and initialised once, and can be used again and again
    unsigned char      *pUncompressBuffer;
    unsigned int         UncompressBufferLen;
    unsigned long long   BytesVerified;
    unsigned long long   DeviceSize;
+   t_AffSegmentFooter   SegmentFooter;  // This header and footer are allocated and initialised only once and re-used afterwards;
+   t_AffSegmentHeader   SegmentHeader;  // SegmentHeader.Name isn't used, so ignore compiler warning about flexible array members
 } t_Aaff;
+#pragma GCC diagnostic pop
 
 #define AAFF_MD5_LEN                16
 #define AAFF_SHA1_LEN               20
 #define AAFF_SHA256_LEN             32
 #define AAFF_BADSECTORMARKER_MAXLEN 65536
-unsigned char AaffBadSectorMarker[AAFF_BADSECTORMARKER_MAXLEN];
+static unsigned char AaffBadSectorMarker[AAFF_BADSECTORMARKER_MAXLEN];
 
 // ----------------
 //  Error handling
@@ -134,7 +140,7 @@ unsigned char AaffBadSectorMarker[AAFF_BADSECTORMARKER_MAXLEN];
 
 static APIRET AaffWriteSegment (t_pAaff pAaff, const char *pName, unsigned int Argument, const unsigned char *pData, unsigned int DataLen)
 {
-   unsigned int NameLen0 = strlen(pName);
+   unsigned int NameLen0 = (unsigned int) strlen(pName);
 
    pAaff->SegmentHeader.NameLen    = htonl(NameLen0);
    pAaff->SegmentHeader.DataLen    = htonl(DataLen);
@@ -152,13 +158,13 @@ static APIRET AaffWriteSegment (t_pAaff pAaff, const char *pName, unsigned int A
 
 APIRET AaffWriteSegmentStr (t_pAaff pAaff, const char *pName, unsigned int Argument, const char *pStr)
 {
-   CHK (AaffWriteSegment (pAaff, pName, Argument, (const unsigned char *) pStr, strlen (pStr)))
+   CHK (AaffWriteSegment (pAaff, pName, Argument, (const unsigned char *) pStr, (unsigned int) strlen (pStr)))
    return NO_ERROR;
 }
 
 static APIRET AaffWriteSegmentArg (t_pAaff pAaff, const char *pName, unsigned int Argument)
 {
-   CHK (AaffWriteSegment (pAaff, pName, Argument, NULL, 0))
+   CHK (AaffWriteSegment (pAaff, pName, Argument, nullptr, 0))
    return NO_ERROR;
 }
 
@@ -210,7 +216,7 @@ static APIRET AaffCreateHandle (t_pAaff *ppAaff)
    t_pAaff pAaff;
 
    pAaff = (t_pAaff) UTIL_MEM_ALLOC(sizeof(t_Aaff));
-   if (pAaff == NULL)
+   if (pAaff == nullptr)
       CHK (ERROR_AAFF_MEMALLOC_FAILED)
 
    memset (pAaff, 0, sizeof(t_Aaff));
@@ -233,7 +239,7 @@ static APIRET AaffDestroyHandle (t_pAaff *ppAaff)
 
    memset (pAaff, 0, sizeof(t_Aaff));
    UTIL_MEM_FREE (pAaff);
-   *ppAaff = NULL;
+   *ppAaff = nullptr;
 
    return NO_ERROR;
 }
@@ -244,7 +250,7 @@ APIRET AaffOpen (t_pAaff *ppAaff, const char *pFilename, unsigned long long Devi
    t_pAaff pAaff;
    char     Buff[512];
 
-   *ppAaff = NULL;
+   *ppAaff = nullptr;
 
    // Open file and intialise
    // -----------------------
@@ -256,7 +262,7 @@ APIRET AaffOpen (t_pAaff *ppAaff, const char *pFilename, unsigned long long Devi
    *(pAaff->pFilename) = pFilename;
    pAaff->OpenedForWrite = true;
    pAaff->pFile = fopen64 (pFilename, "w");
-   if (pAaff->pFile == NULL)
+   if (pAaff->pFile == nullptr)
    {
       CHK (AaffDestroyHandle (ppAaff))
       CHK (ERROR_AAFF_CANNOT_CREATE_FILE)
@@ -319,9 +325,9 @@ APIRET AaffPreprocess (t_pAaffPreprocess pPreprocess, unsigned char *pDataIn, un
    int                rc;
    uLongf             LenOut;
 
-//   *ppPreprocess = NULL;
+//   *ppPreprocess = nullptr;
 //   pPreProcess = (t_pAaffPreprocess) UTIL_MEM_ALLOC(sizeof(t_AaffPreprocess));
-//   if (pPreProcess == NULL)
+//   if (pPreProcess == nullptr)
 //      CHK (ERROR_AAFF_MEMALLOC_FAILED)
 //   *ppPreprocess = pPreProcess;
    pPreprocess->Zero       = false;
@@ -337,7 +343,7 @@ APIRET AaffPreprocess (t_pAaffPreprocess pPreprocess, unsigned char *pDataIn, un
    // ---------------
    LenOut = DataLenOut;
    rc = compress2 ((Bytef *)pDataOut, &LenOut, (Bytef *)pDataIn, DataLenIn, CONFIG (AffCompression));
-   pPreprocess->DataLenOut = LenOut;
+   pPreprocess->DataLenOut = (uint) LenOut;
    if (rc != Z_OK)
    {
       if (rc != Z_BUF_ERROR)    // Do not log this one (the destination buffer was too small for the compressed result)
@@ -380,7 +386,7 @@ static APIRET AaffReallocUncompressBuffer (t_pAaff pAaff, unsigned int NewLen)
    if (NewLen > pAaff->UncompressBufferLen)
    {
       pAaff->pUncompressBuffer = (unsigned char *) realloc (pAaff->pUncompressBuffer, NewLen);
-      if (pAaff->pUncompressBuffer == NULL)
+      if (pAaff->pUncompressBuffer == nullptr)
          return ERROR_AAFF_MEMALLOC_FAILED;
       pAaff->UncompressBufferLen = NewLen;
    }
@@ -389,7 +395,7 @@ static APIRET AaffReallocUncompressBuffer (t_pAaff pAaff, unsigned int NewLen)
 
 static unsigned long long AaffGetCurrentSeekPos (t_Aaff *pAaff)
 {
-   return ftello64 (pAaff->pFile);
+   return (quint64) ftello64 (pAaff->pFile);
 }
 
 APIRET AaffGetImageFileSize  (t_Aaff *pAaff, unsigned long long *pSize)
@@ -404,7 +410,7 @@ APIRET AaffGetImageFileSize  (t_Aaff *pAaff, unsigned long long *pSize)
 
    *pSize = AaffGetCurrentSeekPos (pAaff);
 
-   rc = fseeko64 (pAaff->pFile, CurrentSeekPos, SEEK_SET);
+   rc = fseeko64 (pAaff->pFile, (__off64_t) CurrentSeekPos, SEEK_SET);
    if (rc)
       return ERROR_AAFF_CANNOT_SEEK;
 
@@ -425,13 +431,13 @@ static APIRET AaffReadFile (t_Aaff *pAaff, void *pData, unsigned int DataLen)
 APIRET AaffOpen (t_pAaff *ppAaff, const char *pFilename, unsigned long long DeviceSize)
 {
    t_pAaff pAaff;
-   char     Signature[strlen(AFF_HEADER)+1];
+   char     Signature[AFF_HEADER_LEN+1];
 
-   *ppAaff = NULL;
+   *ppAaff = nullptr;
    CHK (AaffCreateHandle (&pAaff))
 
    pAaff->OpenedForWrite = false;
-   pAaff->pUncompressBuffer   = NULL;
+   pAaff->pUncompressBuffer   = nullptr;
    pAaff->UncompressBufferLen = 0;
    pAaff->PagesRead           = 0;
    pAaff->BytesVerified       = 0;
@@ -442,7 +448,7 @@ APIRET AaffOpen (t_pAaff *ppAaff, const char *pFilename, unsigned long long Devi
       CHK (HashMD5Init (&pAaff->HashContextMD5))
 
    pAaff->pFile = fopen64 (pFilename, "r");
-   if (pAaff->pFile == NULL)
+   if (pAaff->pFile == nullptr)
    {
       UTIL_MEM_FREE (pAaff);
       CHK (ERROR_AAFF_CANNOT_OPEN_FILE)
@@ -631,10 +637,10 @@ APIRET AaffInit (void)
    CHK (TOOL_ERROR_REGISTER_CODE (ERROR_AAFF_SECTORSIZE_TOO_BIG     ))
    CHK (TOOL_ERROR_REGISTER_CODE (ERROR_AAFF_UNCOMPRESS_FAILED      ))
 
-   srandom (time (0));
+   srandom ((unsigned int) time (nullptr));
 
    for (i=0; i<AAFF_BADSECTORMARKER_MAXLEN; i++)
-      AaffBadSectorMarker[i] = (char)random();
+      AaffBadSectorMarker[i] = (unsigned char)random();
    strcpy ((char *)AaffBadSectorMarker, AFF_BADSECTOR_HEADER);
 
    return NO_ERROR;
