@@ -9,7 +9,8 @@
 //  Module:         Multithreaded AEWF (AEWF = Advanced EWF)
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -65,29 +66,29 @@
 //  AEWF definitions
 // ------------------
 
-const uchar  AEWF_SIGNATURE[8]  = {0x45, 0x56, 0x46, 0x09, 0x0D, 0x0A, 0xFF, 0x00};
-const uchar  AEWF_STARTOFFIELDS = 0x01;
-const ushort AEWF_ENDOFFIELDS   = 0x0000;
+static const uchar  AEWF_SIGNATURE[8]  = {0x45, 0x56, 0x46, 0x09, 0x0D, 0x0A, 0xFF, 0x00};
+static const uchar  AEWF_STARTOFFIELDS = 0x01;
+static const ushort AEWF_ENDOFFIELDS   = 0x0000;
 
-const char * AEWF_SECTIONNAME_HEADER2 = "header2";
-const char * AEWF_SECTIONNAME_HEADER  = "header" ;
-const char * AEWF_SECTIONNAME_VOLUME  = "volume" ;
-const char * AEWF_SECTIONNAME_SECTORS = "sectors";
-const char * AEWF_SECTIONNAME_TABLE   = "table"  ;
-const char * AEWF_SECTIONNAME_TABLE2  = "table2" ;
-const char * AEWF_SECTIONNAME_DATA    = "data"   ;
-const char * AEWF_SECTIONNAME_ERROR2  = "error2" ;
-const char * AEWF_SECTIONNAME_HASH    = "hash"   ;
-const char * AEWF_SECTIONNAME_DIGEST  = "digest" ;
-const char * AEWF_SECTIONNAME_NEXT    = "next"   ;
-const char * AEWF_SECTIONNAME_DONE    = "done"   ;
+static const char * AEWF_SECTIONNAME_HEADER2 = "header2";
+static const char * AEWF_SECTIONNAME_HEADER  = "header" ;
+static const char * AEWF_SECTIONNAME_VOLUME  = "volume" ;
+static const char * AEWF_SECTIONNAME_SECTORS = "sectors";
+static const char * AEWF_SECTIONNAME_TABLE   = "table"  ;
+static const char * AEWF_SECTIONNAME_TABLE2  = "table2" ;
+static const char * AEWF_SECTIONNAME_DATA    = "data"   ;
+static const char * AEWF_SECTIONNAME_ERROR2  = "error2" ;
+static const char * AEWF_SECTIONNAME_HASH    = "hash"   ;
+static const char * AEWF_SECTIONNAME_DIGEST  = "digest" ;
+static const char * AEWF_SECTIONNAME_NEXT    = "next"   ;
+static const char * AEWF_SECTIONNAME_DONE    = "done"   ;
 
-const unsigned int AEWF_MAX_CHUNK_OFFSETS      = 65534;
-const unsigned int AEWF_MAX_SIZE_SECTIONSECTOR = 0x7FFFFFFF;
+static const unsigned int AEWF_MAX_CHUNK_OFFSETS      = 65534;
+static const unsigned int AEWF_MAX_SIZE_SECTIONSECTOR = 0x7FFFFFFF;
 
-const unsigned int AEWF_COMPRESSED_CHUNK = 0x80000000;
+static const unsigned int AEWF_COMPRESSED_CHUNK = 0x80000000;
 
-const unsigned long long AEWF_SEEK_END = 0xFFFFFFFFFFFFFFFFULL;
+static const unsigned long long AEWF_SEEK_END = 0xFFFFFFFFFFFFFFFFULL;
 
 typedef struct
 {
@@ -140,8 +141,8 @@ typedef struct
    quint64 BaseOffset;
    uint    Padding2;
    uint    CRC1;
-   uint    OffsetArr[];
-   uint    CRC2;
+   uint    OffsetArr[0];
+   uint    CRC2;          // unused - do not remove or else sizeof calculation become wrong
 } __attribute__ ((packed)) t_AewfSectionTableContents;
 
 typedef struct
@@ -155,8 +156,8 @@ typedef struct
    uint                    NumberOfErrors;
    uchar                   Padding[512];
    uint                    CRC1;
-   t_AewfSectionErrorEntry ErrorArr[];
-   uint                    CRC2;
+   t_AewfSectionErrorEntry ErrorArr[0];
+   uint                    CRC2;     // unused - do not remove or else sizeof calculation become wrong
 } __attribute__ ((packed)) t_AewfSectionErrorContents;
 
 typedef struct
@@ -213,9 +214,9 @@ class t_Aewf
 
       t_Aewf ()
       {
-         pCurrentSegmentFile = NULL;
+         pCurrentSegmentFile = nullptr;
          SegmentFiles        = 0;
-         pVerifyBuffer       = NULL;
+         pVerifyBuffer       = nullptr;
          VerifyBufferLen     = 0;
 
          memcpy (FileHeaderCache.Signature, AEWF_SIGNATURE, sizeof (AEWF_SIGNATURE));
@@ -235,12 +236,12 @@ class t_Aewf
 // ----------------
 //   Global vars
 // ----------------
-unsigned char *pAewfZeroBlockCompressed;
-ulong           AewfZeroBlockCompressedLen;
-ulong           AewfZeroBlockUnCompressedLen;
+static unsigned char *pAewfZeroBlockCompressed;
+static ulong           AewfZeroBlockCompressedLen;
+static ulong           AewfZeroBlockUnCompressedLen;
 
-int             AewfZipCompressionLevel;
-uchar           AewfEwfCompressionLevel;
+static int             AewfZipCompressionLevel;
+static uchar           AewfEwfCompressionLevel;
 
 // ----------------
 //  Error handling
@@ -270,7 +271,7 @@ static int AewfCRC (const void *pBuffer, size_t Len)
 // thus cannot be used on Windows systems with their inconsistent usage of \ and / ).
 // Guymager suports 2 ways for continuing beyond extension ZZZ:
 // OLD method:
-//    Here I decided to continue with ZZZxxx, where xxx represents a numbers from 000 to ZZZ in base36 notation (i.e.
+//    Here I decided to continue with ZZZxxx, where xxx represents a number from 000 to ZZZ in base36 notation (i.e.
 //    0-9 and A-Z). After that, it would continue with ZZZxxxx and so on.
 // FTK method
 //   According to tests made by Willi Spiegel, FTK continues with E14972, E14973 and so on.
@@ -383,7 +384,7 @@ static APIRET AewfSetCurrentSeekPos (t_Aewf *pAewf, quint64 SeekPos)
 {
    int rc;
 
-   if (pAewf->pCurrentSegmentFile == NULL)
+   if (pAewf->pCurrentSegmentFile == nullptr)
       CHK (ERROR_AEWF_NO_FILE_OPEN)
 
    if (SeekPos == AEWF_SEEK_END)
@@ -400,7 +401,7 @@ static APIRET AewfSetCurrentSeekPos (t_Aewf *pAewf, quint64 SeekPos)
 
 static inline APIRET AewfWriteFile (t_pAewf pAewf, const void *pBuffer, size_t Len)
 {
-   if (pAewf->pCurrentSegmentFile == NULL)
+   if (pAewf->pCurrentSegmentFile == nullptr)
       CHK (ERROR_AEWF_NO_FILE_OPEN)
 
    CHK_FWRITE (fwrite (pBuffer, Len, 1, pAewf->pCurrentSegmentFile))
@@ -431,9 +432,9 @@ static APIRET AewfCreateFile (t_Aewf *pAewf)
    // Simulate cases open error
    // static int FakeOpenError=0;
    // if (FakeOpenError++ == 2)
-   //  pAewf->pCurrentSegmentFile = NULL;
+   //  pAewf->pCurrentSegmentFile = nullptr;
 
-   if (pAewf->pCurrentSegmentFile == NULL)
+   if (pAewf->pCurrentSegmentFile == nullptr)
       CHK (ERROR_AEWF_CANNOT_CREATE_FILE)
 
    pAewf->SegmentFilenameList += Filename;
@@ -458,10 +459,10 @@ static APIRET AewfCloseFile (t_pAewf pAewf)
    FILE *pCurrentSegmentFile = pAewf->pCurrentSegmentFile;
    int    rc, err;
 
-   if (pCurrentSegmentFile == NULL)
+   if (pCurrentSegmentFile == nullptr)
       CHK (ERROR_AEWF_NO_FILE_OPEN)
 
-   pAewf->pCurrentSegmentFile = NULL;
+   pAewf->pCurrentSegmentFile = nullptr;
 
    rc = fflush (pCurrentSegmentFile);
    if (rc)
@@ -495,7 +496,7 @@ static APIRET AewfWriteSection (t_pAewf pAewf, const char *pName, const void *pD
    memset (Section.Padding, 0, sizeof (Section.Padding));
    memset (Section.Name   , 0, sizeof (Section.Name   ));
    strcpy (Section.Name, pName);
-   if ((pData==NULL) && (Len==0))
+   if ((pData==nullptr) && (Len==0))
    {
       Section.NextSectionOffset = qToLittleEndian (AewfGetCurrentSeekPos(pAewf)); // Sections "next" and "done", the only ones without
       Section.SectionSize       = 0;                                              // additional data, refer to themselves and have size set to 0
@@ -620,7 +621,7 @@ static APIRET AewfWriteSectionVolume (t_Aewf *pAewf, bool NameVolume=true)
 static APIRET AewfFinishSectionSectors (t_Aewf *pAewf)
 {
    CHK (AewfSetCurrentSeekPos (pAewf, pAewf->CurrentSectionSectorSeekPos))
-   CHK (AewfWriteSection      (pAewf, AEWF_SECTIONNAME_SECTORS, NULL, pAewf->CurrentSectionSectorContentSize))
+   CHK (AewfWriteSection      (pAewf, AEWF_SECTIONNAME_SECTORS, nullptr, pAewf->CurrentSectionSectorContentSize))
    CHK (AewfSetCurrentSeekPos (pAewf, AEWF_SEEK_END))
 
    pAewf->CurrentSectionSectorSeekPos     = 0;
@@ -735,13 +736,13 @@ static APIRET AewfWriteSectionDigest (t_Aewf *pAewf, const uchar *pMD5, const uc
 
 static APIRET AewfWriteSectionNext (t_Aewf *pAewf)
 {
-   CHK (AewfWriteSection (pAewf, AEWF_SECTIONNAME_NEXT, NULL, 0))
+   CHK (AewfWriteSection (pAewf, AEWF_SECTIONNAME_NEXT, nullptr, 0))
    return NO_ERROR;
 }
 
 static APIRET AewfWriteSectionDone (t_Aewf *pAewf)
 {
-   CHK (AewfWriteSection (pAewf, AEWF_SECTIONNAME_DONE, NULL, 0))
+   CHK (AewfWriteSection (pAewf, AEWF_SECTIONNAME_DONE, nullptr, 0))
    return NO_ERROR;
 }
 
@@ -795,9 +796,9 @@ APIRET AewfPreprocess (t_pAewfPreprocess pPreprocess, uchar *pDataIn, unsigned i
    static bool        FirstCall=true;
    static int         CharCount=0;
 #endif
-//   *ppPreprocess = NULL;
+//   *ppPreprocess = nullptr;
 //   pPreProcess = (t_pAewfPreprocess) UTIL_MEM_ALLOC(sizeof(t_AewfPreprocess));
-//   if (pPreProcess == NULL)
+//   if (pPreProcess == nullptr)
 //      CHK (ERROR_AEWF_MEMALLOC_FAILED)
 //   *ppPreprocess = pPreProcess;
    pPreprocess->Compressed = false;
@@ -860,7 +861,7 @@ APIRET AewfWrite (t_Aewf *pAewf, t_AewfPreprocess *pPreprocess, const uchar *pDa
    uint    OffsetArrEntry;
    uint    NewLen;
 
-   if (pAewf->pCurrentSegmentFile == NULL)
+   if (pAewf->pCurrentSegmentFile == nullptr)
       CHK (ERROR_AEWF_NO_FILE_OPEN)
 
 //   printf ("\nChunk: %d  %u bytes - %s", pAewf->ChunkOffsets, DataLen, pPreprocess->Compressed ? "compressed" : "uc");
@@ -909,7 +910,7 @@ APIRET AewfWrite (t_Aewf *pAewf, t_AewfPreprocess *pPreprocess, const uchar *pDa
    {
       pAewf->CurrentSectionSectorSeekPos = AewfGetCurrentSeekPos(pAewf);
       pAewf->ChunkBaseOffset             = AewfGetCurrentSeekPos(pAewf);  // We also could do this after section "sectors" has been written (thus gaining 76 bytes), but this mimics ewfacquire behaviour
-      CHK (AewfWriteSection (pAewf, AEWF_SECTIONNAME_SECTORS, NULL, 0))
+      CHK (AewfWriteSection (pAewf, AEWF_SECTIONNAME_SECTORS, nullptr, 0))
    }
    OffsetArrEntry = AewfGetCurrentSeekPos(pAewf) - pAewf->ChunkBaseOffset;
    if (pPreprocess->Compressed)
@@ -949,7 +950,7 @@ APIRET AewfClose (t_pAewf *ppAewf, QList<quint64> &BadSectors, const uchar *pMD5
       CHK (AewfCloseFile (pAewf))
    }
    delete pAewf;
-   *ppAewf = NULL;
+   *ppAewf = nullptr;
 
    return NO_ERROR;
 }
@@ -971,7 +972,7 @@ static APIRET AewfReallocVerifyBuffer (t_Aewf *pAewf, uint Len)
    if (pAewf->VerifyBufferLen < Len)
    {
       pAewf->pVerifyBuffer = (uchar *) realloc (pAewf->pVerifyBuffer, Len);
-      if (pAewf->pVerifyBuffer == NULL)
+      if (pAewf->pVerifyBuffer == nullptr)
          CHK (ERROR_AEWF_MEMALLOC_FAILED)
       pAewf->VerifyBufferLen = Len;
    }
@@ -999,7 +1000,7 @@ APIRET AewfClose (t_pAewf *ppAewf)
       free (pAewf->pVerifyBuffer);  // Must released with free, as realloc is used for allocating it
 
    delete (pAewf);
-   *ppAewf = NULL;
+   *ppAewf = nullptr;
 
    return NO_ERROR;
 }
@@ -1164,7 +1165,7 @@ APIRET AewfReadNextChunk (t_Aewf *pAewf, uchar *pData, uint *pDataLen, QString *
 
 //      printf ("\nOpening %s", QSTR_TO_PSZ(Filename));
       pAewf->pCurrentSegmentFile = fopen64 (QSTR_TO_PSZ(Filename), "r");
-      if (pAewf->pCurrentSegmentFile == NULL)
+      if (pAewf->pCurrentSegmentFile == nullptr)
          CHK_LOG (pAewf, ERROR_AEWF_CANNOT_OPEN_FILE)
 
       if (CONFIG(CalcImageFileMD5))
@@ -1196,7 +1197,7 @@ APIRET AewfReadNextChunk (t_Aewf *pAewf, uchar *pData, uint *pDataLen, QString *
             LOG_ERROR ("UtilClose returned %d (errno %d - %s)", ret, err, strerror(err));
             CHK_LOG (pAewf, ERROR_AEWF_CANNOT_CLOSE_FILE)
          }
-         pAewf->pCurrentSegmentFile = NULL;
+         pAewf->pCurrentSegmentFile = nullptr;
 
          *pDataLen         = 0;
          *pSegmentFilename = pAewf->SegmentFilenameList[pAewf->SegmentFiles-1];
@@ -1285,6 +1286,7 @@ unsigned int AewfPreprocessExtraSpace (uint FifoBlockSize)
 APIRET AewfInit (void)
 {
    CHK (TOOL_ERROR_REGISTER_CODE (ERROR_AEWF_MEMALLOC_FAILED            ))
+   CHK (TOOL_ERROR_REGISTER_CODE (ERROR_AEWF_CANNOT_CREATE_FILE         ))
    CHK (TOOL_ERROR_REGISTER_CODE (ERROR_AEWF_CANNOT_WRITE_FILE          ))
    CHK (TOOL_ERROR_REGISTER_CODE (ERROR_AEWF_ANOTHER_FILE_STILL_OPEN    ))
    CHK (TOOL_ERROR_REGISTER_CODE (ERROR_AEWF_NO_FILE_OPEN               ))
@@ -1331,7 +1333,7 @@ APIRET AewfInit (void)
    AewfZeroBlockCompressedLen   = UtilGetMaxZcompressedBufferSize (AewfZeroBlockUnCompressedLen);
    pZeroBuff                    = (unsigned char *) malloc (AewfZeroBlockUnCompressedLen);
    pAewfZeroBlockCompressed     = (unsigned char *) malloc (AewfZeroBlockUnCompressedLen);
-   if ((pZeroBuff == NULL) || (pAewfZeroBlockCompressed == NULL))
+   if ((pZeroBuff == nullptr) || (pAewfZeroBlockCompressed == nullptr))
       CHK (ERROR_AEWF_MEMALLOC_FAILED)
    memset (pZeroBuff, 0, AewfZeroBlockUnCompressedLen);
 
@@ -1341,7 +1343,7 @@ APIRET AewfInit (void)
 
    free (pAewfZeroBlockCompressed);                                   // Realloc compressed to the size that is really needed
    pAewfZeroBlockCompressed = (unsigned char *) malloc (AewfZeroBlockCompressedLen);
-   if (pAewfZeroBlockCompressed == NULL)
+   if (pAewfZeroBlockCompressed == nullptr)
       CHK (ERROR_AEWF_MEMALLOC_FAILED)
 
    rc = compress2 ((Bytef*)pAewfZeroBlockCompressed, &AewfZeroBlockCompressedLen, (Bytef*)pZeroBuff, AewfZeroBlockUnCompressedLen, 9);
