@@ -993,13 +993,14 @@ APIRET t_DeviceList::MatchDevice (t_pcDevice pDevCmp, t_pDevice &pDevMatch)
       else  // Not a special device, we can use normal matching
       {
 // Lines below commented out, as somebody might change assignement of the devices starting with the names shown below after Guymager has done a device scan
-//         if ((pDevMatch->LinuxDevice.startsWidth("/dev/loop") ||  // These are devices generated internally by the loop device driver,
-//             (pDevMatch->LinuxDevice.startsWidth("/dev/dm-" ) ||  // LVM or DM. we can be sure that they have unique names, so let's
-//             (pDevMatch->LinuxDevice.startsWidth("/dev/md"  ))    // avoid all the problems with empty serial numbers and so on.
-//         {
-//            Found = (pDevMatch->LinuxDevice == pDevCmp->LinuxDevice);
-//         }
-//         else
+         if (pDevMatch->LinuxDevice.startsWith("/dev/loop") ||  // These are devices generated internally by the loop device driver,
+             pDevMatch->LinuxDevice.startsWith("/dev/dm-" ) ||  // LVM or DM. we can be sure that they have unique names, so let's
+             pDevMatch->LinuxDevice.startsWith("/dev/mapper") || 
+             pDevMatch->LinuxDevice.startsWith("/dev/md"  ))    // avoid all the problems with empty serial numbers and so on.
+         {
+            Found = (pDevMatch->LinuxDevice == pDevCmp->LinuxDevice);
+         }
+         else
               if (pDevMatch->SerialNumber.isEmpty())
          {
             Found = (pDevCmp->SerialNumber.isEmpty() && (pDevMatch->GetState() != t_Device::AcquirePaused) &&
