@@ -7,7 +7,8 @@
 //                  Section Nouvelles Technologies
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -25,8 +26,8 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#ifndef __DEVICE_H__
-#define __DEVICE_H__
+#ifndef DEVICE_H
+#define DEVICE_H
 
 #include "hash.h"
 
@@ -196,8 +197,10 @@ class t_Device
       {
          Idle,
          Queued,
-         Acquire,
-         AcquirePaused,
+         Launch,          // The two Launch states have been introduced for handling the situation where device is replaced by another one and user starts
+         LaunchPaused,    // acquistion without device rescan. State moves to from Launch to Acquire on first rescan if the device is found and its path is
+         Acquire,         // still the same. LaunchPaused already is an error (detected by read thread). It happens if read thread detects the error before
+         AcquirePaused,   // the rescan. Anyway, the final cleanup is always done in t_MainWindow::SlotScanFinished.
          Verify,
          VerifyPaused,
          Cleanup,
@@ -214,6 +217,7 @@ class t_Device
                None = 0,
                UserRequest,
                AcquisitionStartFailed,
+               DeviceMovedOnLaunch,
                ReadError,
                TooManyBadSectors,
                DisconnectTimeout,
@@ -536,8 +540,10 @@ class t_DeviceList: public QList<t_pDevice>
       t_pDevice AppendNew (const QString &SerialNumber, const QString &LinuxDevice, const QString &Model,
                            quint64 SectorSize, quint64 SectorSizePhys, quint64 Size=0);
 
-      APIRET MatchDevice            (t_pcDevice pDevCmp, t_pDevice &pDevMatch);
-      bool   UsedAsCloneDestination (t_pcDevice pDevChk);
+      APIRET  MatchDevice                (t_pcDevice pDevCmp, t_pDevice &pDevMatch);
+      bool    UsedAsCloneDestination     (t_pcDevice pDevChk);
+      QString GetOverallAcquisitionSpeed (void);
+
 };
 
 typedef t_DeviceList *t_pDeviceList;
