@@ -9,7 +9,8 @@
 //  Module:         Dialog that is opened when aborting an acquisition
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -27,10 +28,10 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#ifndef __DLGABORT_H__
-#define __DLGABORT_H__
+#ifndef DLGABORT_H
+#define DLGABORT_H
 
-#ifndef __COMMON_H__
+#ifndef COMMON_H
    #include "common.h"
 #endif
 
@@ -40,7 +41,7 @@
    #include <QtGui>     //lint !e537 Repeated include
 #endif
 
-#ifndef __DEVICE_H__
+#ifndef DEVICE_H
   #include "device.h"
 #endif
 
@@ -52,7 +53,7 @@ class t_DlgAbort: public QDialog
 
    public:
       t_DlgAbort ();
-      t_DlgAbort (t_pcDevice pDevice, QWidget *pParent=NULL, Qt::WindowFlags Flags=0);
+      t_DlgAbort (t_pcDevice pDevice, QWidget *pParent=nullptr, Qt::WindowFlags Flags=0);
      ~t_DlgAbort ();
 
       static APIRET Show (t_pcDevice pDevice, bool &Abort, bool &Delete);
@@ -64,6 +65,7 @@ class t_DlgAbort: public QDialog
 enum
 {
    ERROR_DLGABORT_CONSTRUCTOR_NOT_SUPPORTED = ERROR_BASE_DLGABORT + 1,
+   ERROR_DLGABORT_INVALID_CONFIG_SETTING
 };
 
 #endif
