@@ -9,7 +9,8 @@
 //  Module:         Different message boxes we need all the time
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -64,7 +65,6 @@ t_DlgMessage::t_DlgMessage (const QString &Title, QString Message, bool Monospac
    :QDialog (pParent, Flags)
 {
    static bool  Initialised = false;
-   QSize        MaxSize;
    QFont      *pFont;
 
    if (!Initialised)
@@ -199,30 +199,29 @@ t_MessageBox::~t_MessageBox ()
 {
 }
 
-QMessageBox::StandardButton t_MessageBox::showNewMessageBox(QWidget *parent, QMessageBox::Icon icon, const QString& title, const QString& text, QMessageBox::StandardButtons buttons, QMessageBox::StandardButton defaultButton)
+QMessageBox::StandardButton t_MessageBox::showNewMessageBox(QWidget *pParent, QMessageBox::Icon Icon, const QString &Title, const QString &Text, QMessageBox::StandardButtons Buttons, QMessageBox::StandardButton DefaultButton)
 {
-   t_MessageBox      msgBox(icon, title, text, QMessageBox::NoButton, parent);
-   QDialogButtonBox *buttonBox = msgBox.findChild<QDialogButtonBox*>();
-   Q_ASSERT(buttonBox != 0);
+   t_MessageBox       MsgBox (Icon, Title, Text, QMessageBox::NoButton, pParent);
+   QDialogButtonBox *pButtonBox = MsgBox.findChild<QDialogButtonBox*>();
 
-   uint mask = QMessageBox::FirstButton;
-   while (mask <= QMessageBox::LastButton)
+   Q_ASSERT (pButtonBox != nullptr);
+   uint ButtonMask = QMessageBox::FirstButton;
+   while (ButtonMask <= QMessageBox::LastButton)
    {
-      uint sb = buttons & mask;
-      mask <<= 1;
-      if (!sb)
+      uint CurrentButton = Buttons & ButtonMask;
+      ButtonMask <<= 1;
+      if (!CurrentButton)
          continue;
-      QPushButton *button = msgBox.addButton((QMessageBox::StandardButton)sb);
-      // Choose the first accept role as the default
-      if (msgBox.defaultButton())
+      QPushButton *pPushbutton = MsgBox.addButton ((QMessageBox::StandardButton)CurrentButton);
+      if (MsgBox.defaultButton())  // Do we already have set the  default button?
          continue;
-      if ((defaultButton == QMessageBox::NoButton && buttonBox->buttonRole(button) == QDialogButtonBox::AcceptRole) ||
-          (defaultButton != QMessageBox::NoButton && sb == uint(defaultButton)))
-         msgBox.setDefaultButton(button);
+      if ((DefaultButton == QMessageBox::NoButton && pButtonBox->buttonRole(pPushbutton) == QDialogButtonBox::AcceptRole) ||
+          (DefaultButton != QMessageBox::NoButton && CurrentButton == uint(DefaultButton)))
+         MsgBox.setDefaultButton (pPushbutton);
    }
-   if (msgBox.exec() == -1)
+   if (MsgBox.exec() == -1)
       return QMessageBox::Cancel;
-   return msgBox.standardButton(msgBox.clickedButton());
+   return MsgBox.standardButton (MsgBox.clickedButton());
 }
 
 QMessageBox::StandardButton t_MessageBox::question(QWidget *parent, const QString &title, const QString& text, StandardButtons buttons, StandardButton defaultButton)
