@@ -9,7 +9,8 @@
 //  Module:         Different message dialogs and boxes we need all the time
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -27,10 +28,10 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#ifndef __DLGMESSAGE_H__
-#define __DLGMESSAGE_H__
+#ifndef DLGMESSAGE_H
+#define DLGMESSAGE_H
 
-#ifndef __COMMON_H__
+#ifndef COMMON_H
    #include "common.h"
 #endif
 
@@ -48,12 +49,12 @@ class t_DlgMessage: public QDialog
 
    public:
       t_DlgMessage ();
-      t_DlgMessage (const QString &Title, QString Message, bool Monospaced=false, QWidget *pParent=NULL, Qt::WindowFlags Flags=0);
+      t_DlgMessage (const QString &Title, QString Message, bool Monospaced=false, QWidget *pParent=nullptr, Qt::WindowFlags Flags=0);
      ~t_DlgMessage ();
 
       void AdjustGeometry (void);
 
-      static APIRET Show (const QString &Title, const QString &Message, bool Monospaced=false, QWidget *pParent=NULL, Qt::WindowFlags Flags=0);
+      static APIRET Show (const QString &Title, const QString &Message, bool Monospaced=false, QWidget *pParent=nullptr, Qt::WindowFlags Flags=0);
 
    private:
       t_DlgMessageLocal *pOwn;
