@@ -9,7 +9,8 @@
 //  Module:         Error handling utilities
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -27,8 +28,8 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#ifndef __ERROR_H__
-#define __ERROR_H__
+#ifndef ERROR_H
+#define ERROR_H
 
 // -----------------------
 //       Exit codes
@@ -57,7 +58,7 @@ APIRET ErrorDeInit (void);
 
 #define CHK_QT(Func)                                              \
    {                                                              \
-      if (Func == 0)                                              \
+      if (!(Func))                                                \
       {                                                           \
          (void)ToolErrorCheck (__FFL__, ERROR_QT_UNSUCCESSFUL);   \
          return ERROR_QT_UNSUCCESSFUL;                            \
@@ -67,14 +68,14 @@ APIRET ErrorDeInit (void);
 
 #define CHK_QT_POPUP(Func)                                        \
    {                                                              \
-      if (Func == 0)                                              \
+      if (!(Func))                                                \
          ErrorPopupExit (__FFL__, ERROR_QT_UNSUCCESSFUL, "Qt returned FALSE");  \
    }
 
 
 #define CHK_QT_EXIT(Func)                                         \
    {                                                              \
-      if (Func == 0)                                              \
+      if (!(Func))                                                \
       {                                                           \
          (void)ToolErrorCheck (__FFL__, ERROR_QT_UNSUCCESSFUL);   \
          exit (EXIT_QT_FATAL);                                    \
