@@ -9,7 +9,8 @@
 //  Module:         The central queues for pipelined data processing
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -80,7 +81,7 @@ t_FifoMemory::t_FifoMemory (unsigned int TotalBlocks, unsigned int AllocBlockSiz
    oAllocBlockSize = AllocBlockSize;
 
    poBuf = (char *) malloc (TotalBlocks * AllocBlockSize + PageSize);
-   if (poBuf == NULL)
+   if (poBuf == nullptr)
       CHK_EXIT (ERROR_FIFO_MEMORY_ALLOC_FAILED)
 
    // Calculate offset to have the buffers always lie on a page boundary
@@ -101,9 +102,11 @@ t_FifoMemory::~t_FifoMemory (void)
 }
 
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wstrict-overflow"
 char *t_FifoMemory::GetBlock (unsigned int Size)
 {
-   char *pBlock = NULL;
+   char *pBlock = nullptr;
 
    if (Size > oAllocBlockSize)
    {
@@ -112,11 +115,12 @@ char *t_FifoMemory::GetBlock (unsigned int Size)
    }
    oMutex.lock();
       if (!oFreeBlocks.isEmpty())
-         pBlock = oFreeBlocks.pop();
+         pBlock = oFreeBlocks.pop();  // Warning strict-overflow occurs because of this line... reason never was found and warning thus has been switched off for this function.
    oMutex.unlock();
 
    return pBlock;
 }
+#pragma GCC diagnostic pop
 
 
 void t_FifoMemory::ReleaseBlock (char *pBlock)
@@ -166,10 +170,10 @@ APIRET FifoMemoryAlloc (t_pFifoMemory *ppFifoMemory, unsigned int TotalBlocks, u
 
 APIRET FifoMemoryFree (t_pFifoMemory *ppFifoMemory)
 {
-   if (*ppFifoMemory == NULL)
+   if (*ppFifoMemory == nullptr)
       CHK_EXIT (ERROR_FIFO_MEMORY_NOT_ALLOCATED)
    delete *ppFifoMemory;
-   *ppFifoMemory = NULL;
+   *ppFifoMemory = nullptr;
 
    return NO_ERROR;
 }
@@ -184,7 +188,7 @@ APIRET t_Fifo::Create (t_pFifoMemory pFifoMemory, t_pFifoBlock &pBlock, unsigned
         pBlock = (t_pFifoBlock) pFifoMemory->GetBlock (AllocSize);
    else pBlock = (t_pFifoBlock) UTIL_MEM_ALLOC        (AllocSize);
 
-   if (pBlock == NULL)
+   if (pBlock == nullptr)
       CHK_CONST (ERROR_FIFO_MALLOC_FAILED)
 //   memset (pBlock, 0xAA, sizeof(t_FifoBlock) + BufferSize);
 
@@ -200,8 +204,8 @@ APIRET t_Fifo::Create (t_pFifoMemory pFifoMemory, t_pFifoBlock &pBlock, unsigned
 //   pBlock->EwfChunkCRC        = 0;
 //   pBlock->EwfWriteCRC        = 0;
 
-//   pBlock->pAaffPreprocess    = NULL;
-//   pBlock->pAewfPreprocess    = NULL;
+//   pBlock->pAaffPreprocess    = nullptr;
+//   pBlock->pAewfPreprocess    = nullptr;
 
    pBlock->Nr                 = FIFO_NR_NOTSET;
 
@@ -219,8 +223,8 @@ APIRET t_Fifo::Create (t_pFifoMemory pFifoMemory, t_pFifoBlock &pBlock, unsigned
 
 APIRET t_Fifo::Duplicate(t_pFifoMemory pFifoMemory, t_pFifoBlock pBlockSrc, t_pFifoBlock &pBlockDst)
 {
-   pBlockDst = NULL;
-   if (pBlockSrc == NULL)  // Dummy block
+   pBlockDst = nullptr;
+   if (pBlockSrc == nullptr)  // Dummy block
       return NO_ERROR;
 
    unsigned int AllocSize = pBlockSrc->BufferSize + sizeof(t_FifoBlock);
@@ -229,7 +233,7 @@ APIRET t_Fifo::Duplicate(t_pFifoMemory pFifoMemory, t_pFifoBlock pBlockSrc, t_pF
         pBlockDst = (t_pFifoBlock) pFifoMemory->GetBlock (AllocSize);
    else pBlockDst = (t_pFifoBlock) UTIL_MEM_ALLOC        (AllocSize);
 
-   if (pBlockDst == NULL)
+   if (pBlockDst == nullptr)
       CHK_CONST (ERROR_FIFO_MALLOC_FAILED)
 
    memcpy (pBlockDst, pBlockSrc, AllocSize);
@@ -242,12 +246,12 @@ APIRET t_Fifo::Duplicate(t_pFifoMemory pFifoMemory, t_pFifoBlock pBlockSrc, t_pF
    return NO_ERROR;
 }
 
-//lint -save -e661 -e826 -esym(613,pBlock) Possible access of out-of-bounds pointer, suspicious ptr to ptr conversion, possible use of NULL pointer
+//lint -save -e661 -e826 -esym(613,pBlock) Possible access of out-of-bounds pointer, suspicious ptr to ptr conversion, possible use of nullptr
 APIRET t_Fifo::Destroy (t_pFifoMemory pFifoMemory, t_pFifoBlock &pBlock)
 {
    int TotalSize;
 
-   if (pBlock == NULL)
+   if (pBlock == nullptr)
       CHK (ERROR_FIFO_DOUBLE_FREE)
 
    if (pBlock->MagicStart != FIFO_MAGIC_START)
@@ -268,7 +272,7 @@ APIRET t_Fifo::Destroy (t_pFifoMemory pFifoMemory, t_pFifoBlock &pBlock)
    if (CONFIG(FifoMemoryManager))
         pFifoMemory->ReleaseBlock ((char *)pBlock);
    else UTIL_MEM_FREE             (        pBlock);
-   pBlock = NULL;
+   pBlock = nullptr;
 
    MutexGlobal.lock();
    Frees++;
@@ -333,7 +337,7 @@ t_FifoStd::t_FifoStd (t_pFifoMemory pFifoMemory, int MaxBlocks)
    pOwn = new t_FifoStdLocal;
    pOwn->pFifoMemory = pFifoMemory;
    pOwn->MaxBlocks   = MaxBlocks;
-   pOwn->pFifoDup    = NULL;
+   pOwn->pFifoDup    = nullptr;
 
    pOwn->pSemEmptyBlocks = new QSemaphore (MaxBlocks);
    pOwn->pSemUsedBlocks  = new QSemaphore (0);
@@ -361,7 +365,7 @@ t_FifoStd::~t_FifoStd ()
 
 APIRET t_FifoStd::DupFifo (t_pFifo *ppFifo)
 {
-   *ppFifo = NULL;
+   *ppFifo = nullptr;
 
    if (pOwn->pFifoDup)
       return ERROR_FIFO_ALREADY_DUPLICATED;
@@ -392,7 +396,7 @@ APIRET t_FifoStd::Insert (t_pFifoBlock pBlock)
 
 APIRET t_FifoStd::InsertDummy (void)
 {
-   CHK (Insert (NULL));
+   CHK (Insert (nullptr));
    return NO_ERROR;
 }
 
@@ -436,7 +440,7 @@ APIRET t_FifoStd::Usage (int &Percent)
 
 
 // Qt provides no possibility for waking threads waiting for semaphores. This fn wakes a potential
-// thread hanging in t_FifoStd::Get by inserting a NULL element into the Fifo. Threads hanging in
+// thread hanging in t_FifoStd::Get by inserting a nullptr element into the Fifo. Threads hanging in
 // t_FifoStd::Insert are woken by removing a block from the Fifo. Of course, this method is not really
 // clean, as it not only wakes threads but manipulates the data in the Fifo... the threads accessing
 // the Fifo must be able to cope with this.
@@ -450,7 +454,7 @@ APIRET t_FifoStd::WakeWaitingThreads (void)
 
    WouldBlock = !pOwn->pSemUsedBlocks->tryAcquire();
    if (WouldBlock)                         // If this access would block there might be a thread waiting in "Get"
-        CHK (Insert (NULL))
+        CHK (Insert (nullptr))
    else pOwn->pSemUsedBlocks->release();
 
    WouldBlock = !pOwn->pSemEmptyBlocks->tryAcquire();
@@ -502,7 +506,7 @@ static APIRET FifoCompressInit (t_FifoCompressLocal **ppOwn, t_pFifoMemory pFifo
 
    (*ppOwn)->NextSubFifoNr = 0;
    (*ppOwn)->pMutexQueue   = new QMutex();
-   (*ppOwn)->pFifoDup      = NULL;
+   (*ppOwn)->pFifoDup      = nullptr;
    (*ppOwn)->Dup           = false;
 
    return NO_ERROR;
@@ -524,7 +528,7 @@ static APIRET FifoCompressDeInit (t_FifoCompressLocal *pOwn, bool RemoveSubFifos
 
 t_FifoCompressIn::t_FifoCompressIn (void)
 {
-   pOwn=NULL;   //lint -esym(613,t_FifoCompressIn::pOwn)  Prevent lint from telling us about possible null pointers in the following code
+   pOwn=nullptr;   //lint -esym(613,t_FifoCompressIn::pOwn)  Prevent lint from telling us about possible null pointers in the following code
    CHK_EXIT (ERROR_FIFO_CONSTRUCTOR_NOT_SUPPORTED)
 }
 
@@ -568,7 +572,7 @@ APIRET t_FifoCompressIn::Insert (t_pFifoBlock pBlock)
 APIRET t_FifoCompressIn::InsertDummy (void)
 {
    for (int i=0; i< pOwn->FifoArrLen; i++)
-      CHK (Insert (NULL))
+      CHK (Insert (nullptr))
 
    return NO_ERROR;
 }
@@ -626,7 +630,7 @@ APIRET t_FifoCompressIn::WakeWaitingThreads (void)
 
 t_FifoCompressOut::t_FifoCompressOut ()
 {
-   pOwn = NULL;   //lint -esym(613,t_FifoCompressOut::pOwn)  Prevent lint from telling us about possible null pointers in the following code
+   pOwn = nullptr;   //lint -esym(613,t_FifoCompressOut::pOwn)  Prevent lint from telling us about possible null pointers in the following code
    CHK_EXIT (ERROR_FIFO_CONSTRUCTOR_NOT_SUPPORTED)
 }
 
@@ -638,11 +642,11 @@ t_FifoCompressOut::t_FifoCompressOut (t_pFifoCompressOut pFifoSrc)
    pOwn->ppFifoArr      = (t_pFifoStd *) UTIL_MEM_ALLOC ((size_t)pOwn->FifoArrLen * sizeof(t_pFifoStd));
 
    for (int i=0; i<pOwn->FifoArrLen; i++)
-      pOwn->ppFifoArr[i] = NULL;
+      pOwn->ppFifoArr[i] = nullptr;
 
    pOwn->NextSubFifoNr = 0;
    pOwn->pMutexQueue   = new QMutex();
-   pOwn->pFifoDup      = NULL;
+   pOwn->pFifoDup      = nullptr;
    pOwn->Dup           = true;
 }
 
@@ -699,7 +703,7 @@ APIRET t_FifoCompressOut::InsertDummy (int SubFifoNr)
    t_pFifoStd pFifo;
 
    CHK (GetSubFifo (SubFifoNr, pFifo))
-   CHK (pFifo->Insert (NULL))
+   CHK (pFifo->Insert (nullptr))
 
    return NO_ERROR;
 }
