@@ -4,13 +4,13 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="+582"/>
+        <location filename="main.cpp" line="+590"/>
         <source>Guymager needs to be started with root rights in order to perform acquisitions. You are not root and thus won&apos;t be able to acquire devices.
 Continue anyway?</source>
         <translation type="unfinished">GUYMAGER需要以管理员的身份运行，你目前不是管理员权限，确定继续吗？</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1491"/>
+        <location filename="threadwrite.cpp" line="+1504"/>
         <source>Deleting %1</source>
         <translation type="unfinished">删除 %1</translation>
     </message>
@@ -21,9 +21,9 @@ Continue anyway?</source>
         <translation type="unfinished">非管理员权限</translation>
     </message>
     <message>
-        <location filename="dlgabort.cpp" line="+84"/>
-        <location filename="dlgacquire.cpp" line="+812"/>
-        <location filename="dlgdirsel.cpp" line="+107"/>
+        <location filename="dlgabort.cpp" line="+87"/>
+        <location filename="dlgacquire.cpp" line="+813"/>
+        <location filename="dlgdirsel.cpp" line="+108"/>
         <source>Ok</source>
         <translation type="unfinished">确定</translation>
     </message>
@@ -36,7 +36,7 @@ Continue anyway?</source>
         <translation type="unfinished">取消</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="+68"/>
+        <location filename="file.cpp" line="+69"/>
         <source>Linux dd raw image</source>
         <translation type="unfinished"></translation>
     </message>
@@ -51,7 +51,7 @@ Continue anyway?</source>
         <translation type="unfinished">A高级司法镜像</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1441"/>
+        <location filename="threadscan.cpp" line="+1442"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation type="unfinished">GUYMAGER 无法扫描到设备</translation>
     </message>
@@ -148,7 +148,7 @@ remaining</source>
         <translation type="obsolete">剩余时间</translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+50"/>
+        <location filename="mainwindow.h" line="+51"/>
         <source>Model</source>
         <translation type="unfinished">设备名</translation>
     </message>
@@ -260,17 +260,21 @@ remaining</source>
         <translation type="unfinished">你确定终止%1吗？</translation>
     </message>
     <message>
-        <location line="+10"/>
         <source>Delete partial image files</source>
-        <translation type="unfinished">删除部分镜像文件</translation>
+        <translation type="obsolete">删除部分镜像文件</translation>
     </message>
     <message>
-        <location line="-9"/>
+        <location line="+1"/>
         <source>Do you want to abort the verification of %1?</source>
         <translation type="unfinished">你确定终止%1验证吗</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+17"/>
+        <source>Delete image files already created</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+12"/>
         <source>Abort?</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">终止？</translation>
@@ -304,8 +308,8 @@ Do you accept these changes?</source>
 是否同意此项变化</translation>
     </message>
     <message>
-        <location filename="config.h" line="+278"/>
-        <location filename="table.cpp" line="+351"/>
+        <location filename="config.h" line="+287"/>
+        <location filename="table.cpp" line="+352"/>
         <source>EwfCaseNumber</source>
         <translation type="unfinished">案件序列号</translation>
     </message>
@@ -732,7 +736,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+202"/>
+        <location filename="info.cpp" line="+203"/>
         <source>Command executed: %1</source>
         <translation type="unfinished">执行命令：%1</translation>
     </message>
@@ -754,7 +758,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+110"/>
+        <location filename="infofield.cpp" line="+113"/>
         <source>Size</source>
         <translation type="unfinished">大小</translation>
     </message>
@@ -779,12 +783,17 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished">当前速度</translation>
     </message>
     <message>
-        <location line="+17"/>
+        <location line="+5"/>
+        <source>Overall speed (all acquisitions)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+13"/>
         <source>bytes</source>
         <translation type="unfinished">字节</translation>
     </message>
     <message>
-        <location line="-15"/>
+        <location line="-16"/>
         <source>Hash calculation</source>
         <translation type="unfinished">哈希计算</translation>
     </message>
@@ -824,7 +833,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished">镜像校验</translation>
     </message>
     <message>
-        <location line="+88"/>
+        <location line="+91"/>
         <location line="+9"/>
         <location line="+6"/>
         <source>on</source>
@@ -840,7 +849,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished">关闭</translation>
     </message>
     <message>
-        <location line="-114"/>
+        <location line="-117"/>
         <source>Additional state info</source>
         <translation type="unfinished"></translation>
     </message>
@@ -870,7 +879,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+399"/>
+        <location filename="device.cpp" line="+401"/>
         <source>Local device</source>
         <translation type="unfinished">本地设备</translation>
     </message>
@@ -880,7 +889,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished">闲置</translation>
     </message>
     <message>
-        <location line="+60"/>
+        <location line="+66"/>
         <source>Cleanup</source>
         <translation type="unfinished"></translation>
     </message>
@@ -894,7 +903,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="obsolete">中止-错误：原因“none”</translation>
     </message>
     <message>
-        <location line="-355"/>
+        <location line="-362"/>
         <source>Aborted by user</source>
         <translation type="unfinished">用户中断</translation>
     </message>
@@ -907,7 +916,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="obsolete">中止 - 硬盘读取错误</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+292"/>
+        <location filename="mainwindow.cpp" line="+293"/>
         <source>&amp;Rescan</source>
         <translation type="unfinished">&amp;R重新扫描</translation>
     </message>
@@ -923,7 +932,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+160"/>
+        <location line="+190"/>
         <source>There are active acquisitions. Do you really want to abort them and quit?</source>
         <translation type="unfinished">There are active acquisitions. 你确定放弃并退出？</translation>
     </message>
@@ -952,25 +961,21 @@ Using libguytools %5</source>
         <translation type="unfinished">关于GUYMAGER</translation>
     </message>
     <message>
-        <location line="-13"/>
+        <location line="+1"/>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
 Version: %1
-Compilation timestamp: %2
-Compiled with gcc %3
-Linked with libguytools %4
-Linked with libewf %5 %6</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location line="+14"/>
-        <source>GUYMAGER is a Linux-based forensic imaging tool
-
-Version: %1
-Compilation timestamp: %2
+Version timestamp: %2
 Compiled with gcc %3
 Linked with libguytools %4
 Compiled without libewf support</source>
+        <oldsource>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Compiled without libewf support</oldsource>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -986,7 +991,7 @@ Compiled without libewf support</source>
         <translation type="unfinished">退出</translation>
     </message>
     <message>
-        <location line="-355"/>
+        <location line="-385"/>
         <source>&amp;Devices</source>
         <translation type="unfinished">&amp;D设备</translation>
     </message>
@@ -1020,6 +1025,17 @@ Compiled without libewf support</source>
         <comment>Menu entry</comment>
         <translation type="unfinished">关于&amp;QT</translation>
     </message>
+    <message>
+        <location line="+443"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Version timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Linked with libewf %5 %6</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Acquisition running</source>
         <translation type="obsolete">正在获取中</translation>
@@ -1029,7 +1045,7 @@ Compiled without libewf support</source>
         <translation type="obsolete">正在验证中</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="+352"/>
+        <location filename="device.cpp" line="+359"/>
         <source>Device disconnected, acquisition paused</source>
         <translation type="unfinished">设备断开，暂停获取</translation>
     </message>
@@ -1069,7 +1085,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-19"/>
+        <location filename="mainwindow.cpp" line="-462"/>
         <source>Rescan devices and update table</source>
         <translation type="unfinished">扫描设备和更新档</translation>
     </message>
@@ -1117,17 +1133,17 @@ Compiled without libewf support</source>
         <translation type="unfinished">无法选择设备或文件。因为大小为0字节。</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-168"/>
+        <location filename="device.cpp" line="-174"/>
         <source>Used in clone operation</source>
         <translation type="unfinished">用于拷贝操作</translation>
     </message>
     <message>
-        <location line="+15"/>
+        <location line="+17"/>
         <source>Aborting...</source>
         <translation type="unfinished">取消中 ...</translation>
     </message>
     <message>
-        <location line="+163"/>
+        <location line="+167"/>
         <source>none</source>
         <comment>column hidden areas</comment>
         <translation type="unfinished"></translation>
@@ -1144,15 +1160,20 @@ Compiled without libewf support</source>
         <translation type="unfinished">在获取完成后退出</translation>
     </message>
     <message>
-        <location line="+416"/>
+        <location line="+446"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-468"/>
+        <location filename="device.cpp" line="-475"/>
         <source>Acquisition start failure</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Device (re)moved</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+1"/>
         <source>Device read error</source>
@@ -1204,7 +1225,17 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+278"/>
+        <location line="+281"/>
+        <source>Launched, device disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Launched</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>Running</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1214,7 +1245,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+53"/>
+        <location line="+54"/>
         <location line="+26"/>
         <source>Verified &amp; ok</source>
         <comment>Status column</comment>
@@ -1272,7 +1303,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-395"/>
+        <location line="-401"/>
         <source>Too many bad sectors</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1325,7 +1356,7 @@ Compiled without libewf support</source>
         <translation type="unfinished">设备信息</translation>
     </message>
     <message>
-        <location line="+579"/>
+        <location line="+581"/>
         <source>Finished successfully</source>
         <comment>Info file</comment>
         <translation type="unfinished">成功完成</translation>
@@ -1406,7 +1437,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-642"/>
+        <location line="-644"/>
         <source>Linux device:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1418,7 +1449,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+643"/>
+        <location line="+645"/>
         <location line="+24"/>
         <source>Acquisition started:: %1</source>
         <comment>Info file</comment>
@@ -1457,19 +1488,13 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-626"/>
+        <location line="-628"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+1"/>
-        <source>Compilation timestamp:: %1</source>
-        <comment>Info file</comment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location line="+1"/>
+        <location line="+2"/>
         <source>Compiled with:: %1 %2</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1481,13 +1506,13 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+683"/>
+        <location line="+685"/>
         <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-639"/>
+        <location line="-641"/>
         <source>Source verification:: on</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1499,7 +1524,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+507"/>
+        <location line="+509"/>
         <source>(during source verification)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1511,13 +1536,19 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-584"/>
+        <location line="-586"/>
         <source>Image path and file name:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-42"/>
+        <location line="-47"/>
+        <source>Version timestamp:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+5"/>
         <source>(not used as Guymager is configured to use its own EWF module)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1572,7 +1603,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+516"/>
+        <location line="+518"/>
         <source>Aborted, too many bad sectors (&gt; %1)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1640,7 +1671,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-844"/>
+        <location line="-846"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
@@ -1693,7 +1724,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+866"/>
+        <location line="+868"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1709,12 +1740,12 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-881"/>
+        <location line="-883"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+739"/>
+        <location line="+741"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1731,13 +1762,13 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-672"/>
+        <location line="-674"/>
         <source>Hash calculation:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+521"/>
+        <location line="+523"/>
         <source>Aborted because of source read error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1767,13 +1798,13 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-607"/>
+        <location line="-609"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+725"/>
+        <location line="+727"/>
         <source>Acquisition/verification aborted - file list may be incomplete</source>
         <translation type="unfinished"></translation>
     </message>
