@@ -4,9 +4,9 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="dlgabort.cpp" line="+84"/>
-        <location filename="dlgacquire.cpp" line="+812"/>
-        <location filename="dlgdirsel.cpp" line="+107"/>
+        <location filename="dlgabort.cpp" line="+87"/>
+        <location filename="dlgacquire.cpp" line="+813"/>
+        <location filename="dlgdirsel.cpp" line="+108"/>
         <source>Ok</source>
         <translation>Ok</translation>
     </message>
@@ -19,7 +19,7 @@
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="+68"/>
+        <location filename="file.cpp" line="+69"/>
         <source>Linux dd raw image</source>
         <translation>Image brute Linux dd</translation>
     </message>
@@ -29,7 +29,7 @@
         <translation>Format EWF, sous-format %1 </translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+581"/>
+        <location filename="main.cpp" line="+589"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Droits «root»</translation>
@@ -42,7 +42,7 @@ Continue anyway?</source>
 Continuer quand-même?</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1491"/>
+        <location filename="threadwrite.cpp" line="+1504"/>
         <source>Deleting %1</source>
         <translation>Efface %1</translation>
     </message>
@@ -52,7 +52,7 @@ Continuer quand-même?</translation>
         <translation>Format AFF</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1441"/>
+        <location filename="threadscan.cpp" line="+1442"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation>Guymager ne peut déterminer les médias connectés.</translation>
     </message>
@@ -169,7 +169,7 @@ des FIFOs
 [%]</translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+48"/>
+        <location filename="mainwindow.h" line="+49"/>
         <source>SerialNr</source>
         <translation>Nº de
 série</translation>
@@ -301,17 +301,21 @@ actuelle
         <translation>Voulez vous abandonner l&apos;acquisition de %1?</translation>
     </message>
     <message>
-        <location line="+10"/>
         <source>Delete partial image files</source>
-        <translation>Effacer les images partiellement écrites</translation>
+        <translation type="vanished">Effacer les images partiellement écrites</translation>
     </message>
     <message>
-        <location line="-9"/>
+        <location line="+1"/>
         <source>Do you want to abort the verification of %1?</source>
         <translation>Voulez vous abandonner la vérification de %1?</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+17"/>
+        <source>Delete image files already created</source>
+        <translation>Effacer les fichiers image déjà créés</translation>
+    </message>
+    <message>
+        <location line="+12"/>
         <source>Abort?</source>
         <comment>Dialog title</comment>
         <translation>Abandonner?</translation>
@@ -320,8 +324,8 @@ actuelle
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+278"/>
-        <location filename="table.cpp" line="+351"/>
+        <location filename="config.h" line="+287"/>
+        <location filename="table.cpp" line="+352"/>
         <source>EwfCaseNumber</source>
         <translation>Numéro d&apos;affaire</translation>
     </message>
@@ -798,7 +802,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+202"/>
+        <location filename="info.cpp" line="+203"/>
         <source>Command executed: %1</source>
         <translation>Commande  exécutée: %1</translation>
     </message>
@@ -820,7 +824,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+110"/>
+        <location filename="infofield.cpp" line="+113"/>
         <source>Size</source>
         <translation>Capacité</translation>
     </message>
@@ -845,12 +849,17 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation>Vitesse actuelle</translation>
     </message>
     <message>
-        <location line="+17"/>
+        <location line="+5"/>
+        <source>Overall speed (all acquisitions)</source>
+        <translation>Vitesse totale (toutes acquisitions)</translation>
+    </message>
+    <message>
+        <location line="+13"/>
         <source>bytes</source>
         <translation>octets</translation>
     </message>
     <message>
-        <location line="-15"/>
+        <location line="-16"/>
         <source>Hash calculation</source>
         <translation>Calculer valeurs «hash»</translation>
     </message>
@@ -890,7 +899,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation>Vérification image</translation>
     </message>
     <message>
-        <location line="+88"/>
+        <location line="+91"/>
         <location line="+9"/>
         <location line="+6"/>
         <source>on</source>
@@ -906,7 +915,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation>non</translation>
     </message>
     <message>
-        <location line="-114"/>
+        <location line="-117"/>
         <source>Additional state info</source>
         <translation>Informations d&apos;état suppl.</translation>
     </message>
@@ -936,7 +945,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+399"/>
+        <location filename="device.cpp" line="+401"/>
         <source>Local device</source>
         <translation>Média local</translation>
     </message>
@@ -946,7 +955,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation>Libre</translation>
     </message>
     <message>
-        <location line="+60"/>
+        <location line="+66"/>
         <source>Cleanup</source>
         <translation>Nettoyage</translation>
     </message>
@@ -960,7 +969,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation type="obsolete">Abandon - raison «none»</translation>
     </message>
     <message>
-        <location line="-355"/>
+        <location line="-362"/>
         <source>Aborted by user</source>
         <translation>Abandonné par l&apos;utilisateur</translation>
     </message>
@@ -973,7 +982,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation type="obsolete">Abandon - erreur grave de lecture </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+292"/>
+        <location filename="mainwindow.cpp" line="+293"/>
         <source>&amp;Rescan</source>
         <translation>&amp;Actualiser</translation>
     </message>
@@ -1024,7 +1033,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation>Média déjà existant</translation>
     </message>
     <message>
-        <location line="+160"/>
+        <location line="+190"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation>Quitter GUYMAGER</translation>
@@ -1051,12 +1060,28 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
 Version: %1
-Compilation timestamp: %2
+Version timestamp: %2
 Compiled with gcc %3
 Linked with libguytools %4
 Linked with libewf %5 %6</source>
         <translation>GUYMAGER est un outil d&apos;acquisition forensique basé sur Linux
 
+Version: %1
+Date et heure de la version: %2
+Compilé avec gcc %3
+Utilise libguytools %4
+Utilise libewf %5 %6</translation>
+    </message>
+    <message>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Linked with libewf %5 %6</source>
+        <translation type="vanished">GUYMAGER est un outil d&apos;acquisition forensique basé sur Linux
+
 Version: %1
 Date et heure de compilation: %2
 Compilé avec gcc %3
@@ -1068,14 +1093,21 @@ Utilise libewf %5 %6</translation>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
 Version: %1
-Compilation timestamp: %2
+Version timestamp: %2
 Compiled with gcc %3
 Linked with libguytools %4
 Compiled without libewf support</source>
+        <oldsource>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Compiled without libewf support</oldsource>
         <translation>GUYMAGER est un outil d&apos;acquisition forensique basé sur Linux
 
 Version: %1
-Date et heure de compilation: %2
+Date et heure de la version: %2
 Compilé avec gcc %3
 Utilise libguytools %4
 Compilé sans support pour libewf.</translation>
@@ -1111,7 +1143,7 @@ Utilise libguytools %5</translation>
         <translation type="obsolete">Vérification en cours</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="+352"/>
+        <location filename="device.cpp" line="+359"/>
         <source>Device disconnected, acquisition paused</source>
         <translation>Média déconnecté, acquisition suspendue</translation>
     </message>
@@ -1151,7 +1183,7 @@ Utilise libguytools %5</translation>
         <translation>Oui</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-462"/>
+        <location filename="mainwindow.cpp" line="-492"/>
         <source>Rescan devices and update table</source>
         <translation>Actualiser la liste des médias connectés</translation>
     </message>
@@ -1199,17 +1231,17 @@ Utilise libguytools %5</translation>
         <translation>Le fichier ou média ne peut être sélectionné parce que sa taille est de 0 octets.</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-168"/>
+        <location filename="device.cpp" line="-174"/>
         <source>Used in clone operation</source>
         <translation>Occupé par clonage</translation>
     </message>
     <message>
-        <location line="+15"/>
+        <location line="+17"/>
         <source>Aborting...</source>
         <translation>Abandon en cours...</translation>
     </message>
     <message>
-        <location line="+163"/>
+        <location line="+167"/>
         <source>none</source>
         <comment>column hidden areas</comment>
         <translation>aucune</translation>
@@ -1234,7 +1266,7 @@ Utilise libguytools %5</translation>
         <translation type="obsolete">Abandon - Démarrage échoué</translation>
     </message>
     <message>
-        <location line="+416"/>
+        <location line="+446"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation>(inactif, Guymager est configuré d&apos;utiliser son propre module EWF)</translation>
     </message>
@@ -1255,10 +1287,15 @@ Utilise libewf %4 %5
 Utilise libguytools %6</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-468"/>
+        <location filename="device.cpp" line="-475"/>
         <source>Acquisition start failure</source>
         <translation>Démarrage échoué</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Device (re)moved</source>
+        <translation>Média retiré ou changé</translation>
+    </message>
     <message>
         <location line="+1"/>
         <source>Device read error</source>
@@ -1310,7 +1347,17 @@ Utilise libguytools %6</translation>
         <translation>Fichier info 1 erreur d&apos;écriture</translation>
     </message>
     <message>
-        <location line="+278"/>
+        <location line="+281"/>
+        <source>Launched, device disconnected</source>
+        <translation>Acquisition supendue lors du lancement</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Launched</source>
+        <translation>Acquisition lancée</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>Running</source>
         <translation>Acquisition en cours</translation>
     </message>
@@ -1320,7 +1367,7 @@ Utilise libguytools %6</translation>
         <translation>Vérification en cours</translation>
     </message>
     <message>
-        <location line="+53"/>
+        <location line="+54"/>
         <location line="+26"/>
         <source>Verified &amp; ok</source>
         <comment>Status column</comment>
@@ -1383,7 +1430,7 @@ Utilise libguytools %6</translation>
         <translation>Vérification échouée</translation>
     </message>
     <message>
-        <location line="-395"/>
+        <location line="-401"/>
         <source>Too many bad sectors</source>
         <translation>trop de secteurs mauvais</translation>
     </message>
@@ -1430,7 +1477,13 @@ Utilise libguytools %6</translation>
         <translation>Guymager</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+3"/>
+        <source>Version timestamp:: %1</source>
+        <comment>Info file</comment>
+        <translation>Date et heure de la version:: %1</translation>
+    </message>
+    <message>
+        <location line="+5"/>
         <source>(not used as Guymager is configured to use its own EWF module)</source>
         <comment>Info file</comment>
         <translation>(inactif, Guymager est configuré d&apos;utiliser son propre module EWF)</translation>
@@ -1473,7 +1526,7 @@ Utilise libguytools %6</translation>
         <translation>Information média</translation>
     </message>
     <message>
-        <location line="+579"/>
+        <location line="+581"/>
         <source>Finished successfully</source>
         <comment>Info file</comment>
         <translation>Terminé avec succès</translation>
@@ -1554,7 +1607,7 @@ Utilise libguytools %6</translation>
         <translation>Acquisition abandonnée avant de commencer vérification</translation>
     </message>
     <message>
-        <location line="-642"/>
+        <location line="-644"/>
         <source>Linux device:: %1</source>
         <comment>Info file</comment>
         <translation>Média Linux:: %1</translation>
@@ -1566,7 +1619,7 @@ Utilise libguytools %6</translation>
         <translation>Capacité:: %1 (%2)</translation>
     </message>
     <message>
-        <location line="+643"/>
+        <location line="+645"/>
         <location line="+24"/>
         <source>Acquisition started:: %1</source>
         <comment>Info file</comment>
@@ -1605,19 +1658,18 @@ Utilise libguytools %6</translation>
         <translation>Hash MD5:: %1</translation>
     </message>
     <message>
-        <location line="-626"/>
+        <location line="-628"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation>Version:: %1</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Compilation timestamp:: %1</source>
         <comment>Info file</comment>
-        <translation>Date et heure de compilation:: %1</translation>
+        <translation type="vanished">Date et heure de compilation:: %1</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+2"/>
         <source>Compiled with:: %1 %2</source>
         <comment>Info file</comment>
         <translation>Compilé avec gcc:: %1 %2</translation>
@@ -1634,7 +1686,7 @@ Utilise libguytools %6</translation>
         <translation>Version libguytools:: %1</translation>
     </message>
     <message>
-        <location line="+683"/>
+        <location line="+685"/>
         <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
         <comment>Info file</comment>
         <translation>Vitesse de la vérification:: %1 MByte/s (%2 heures, %3 minutes et %4 secondes)</translation>
@@ -1645,7 +1697,7 @@ Utilise libguytools %6</translation>
         <translation type="obsolete">Calculer valeurs hash:: non</translation>
     </message>
     <message>
-        <location line="-639"/>
+        <location line="-641"/>
         <source>Source verification:: on</source>
         <comment>Info file</comment>
         <translation>Relire et vérifier media:: oui</translation>
@@ -1657,7 +1709,7 @@ Utilise libguytools %6</translation>
         <translation>Relire et vérifier media:: non</translation>
     </message>
     <message>
-        <location line="+507"/>
+        <location line="+509"/>
         <source>(during source verification)</source>
         <comment>Info file</comment>
         <translation>(pendant la vérification)</translation>
@@ -1684,7 +1736,7 @@ Utilise libguytools %6</translation>
         <translation type="obsolete">Calculer valeurs hash:: SHA-256</translation>
     </message>
     <message>
-        <location line="-584"/>
+        <location line="-586"/>
         <source>Image path and file name:: %1</source>
         <comment>Info file</comment>
         <translation>Répertoire et fichier image:: %1</translation>
@@ -1708,7 +1760,7 @@ Utilise libguytools %6</translation>
         <translation>Vérification image:: non</translation>
     </message>
     <message>
-        <location line="+516"/>
+        <location line="+518"/>
         <source>Aborted, too many bad sectors (&gt; %1)</source>
         <comment>Info file</comment>
         <translation>Abandonné à cause de trop de secteurs mauvais</translation>
@@ -1776,7 +1828,7 @@ Utilise libguytools %6</translation>
         <translation>Vous pouvez essayer une nouvelle acquisition du média.</translation>
     </message>
     <message>
-        <location line="-844"/>
+        <location line="-846"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation>Effacer média spécial</translation>
@@ -1829,7 +1881,7 @@ Utilise libguytools %6</translation>
         <translation>Occupé par opération de clonage - ne peut être  acquéré</translation>
     </message>
     <message>
-        <location line="+866"/>
+        <location line="+868"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation>Fichiers image et leur valeurs hash MD5</translation>
@@ -1849,12 +1901,12 @@ Utilise libguytools %6</translation>
         <translation>Valeurs hashs MD5 non disponibles (le paramètre de configuration CalcImageFileMD5 est désactivé)</translation>
     </message>
     <message>
-        <location line="-881"/>
+        <location line="-883"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation>Ne peut être acquéré - voir informations d&apos;état suppl.</translation>
     </message>
     <message>
-        <location line="+739"/>
+        <location line="+741"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation>Abandonné à cause d&apos;une erreur lors de l&apos;écriture du fichier info</translation>
@@ -1871,13 +1923,13 @@ Utilise libguytools %6</translation>
         <translation>Valeurs hashs MD5 non disponibles (le format EWF choisi ne supporte pas le calcul des valeurs hash des fichiers image)</translation>
     </message>
     <message>
-        <location line="-672"/>
+        <location line="-674"/>
         <source>Hash calculation:: %1</source>
         <comment>Info file</comment>
         <translation>Calculer valeurs hash:: %1</translation>
     </message>
     <message>
-        <location line="+521"/>
+        <location line="+523"/>
         <source>Aborted because of source read error</source>
         <comment>Info file</comment>
         <translation>Abandonné à cause d&apos;une erreur lors de la lecture du media source</translation>
@@ -1907,13 +1959,13 @@ Utilise libguytools %6</translation>
         <translation>Hash SHA-1 image vérifié:: %1</translation>
     </message>
     <message>
-        <location line="-607"/>
+        <location line="-609"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation>Espaces cachés: %1</translation>
     </message>
     <message>
-        <location line="+725"/>
+        <location line="+727"/>
         <source>Acquisition/verification aborted - file list may be incomplete</source>
         <translation>Abandon de l&apos;acquisition / vérification - la liste de fichiers est probablement incomplète </translation>
     </message>
