@@ -4,9 +4,9 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="dlgabort.cpp" line="+84"/>
-        <location filename="dlgacquire.cpp" line="+812"/>
-        <location filename="dlgdirsel.cpp" line="+107"/>
+        <location filename="dlgabort.cpp" line="+87"/>
+        <location filename="dlgacquire.cpp" line="+813"/>
+        <location filename="dlgdirsel.cpp" line="+108"/>
         <source>Ok</source>
         <translation type="unfinished"></translation>
     </message>
@@ -19,7 +19,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="file.cpp" line="+68"/>
+        <location filename="file.cpp" line="+69"/>
         <source>Linux dd raw image</source>
         <translation type="unfinished"></translation>
     </message>
@@ -29,7 +29,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+581"/>
+        <location filename="main.cpp" line="+589"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -41,7 +41,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1491"/>
+        <location filename="threadwrite.cpp" line="+1504"/>
         <source>Deleting %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -51,7 +51,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1441"/>
+        <location filename="threadscan.cpp" line="+1442"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -94,7 +94,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+48"/>
+        <location filename="mainwindow.h" line="+49"/>
         <source>SerialNr</source>
         <translation type="unfinished"></translation>
     </message>
@@ -197,17 +197,17 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+10"/>
-        <source>Delete partial image files</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location line="-9"/>
+        <location line="+1"/>
         <source>Do you want to abort the verification of %1?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+17"/>
+        <source>Delete image files already created</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+12"/>
         <source>Abort?</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -216,8 +216,8 @@ Continue anyway?</source>
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+278"/>
-        <location filename="table.cpp" line="+351"/>
+        <location filename="config.h" line="+287"/>
+        <location filename="table.cpp" line="+352"/>
         <source>EwfCaseNumber</source>
         <translation type="unfinished"></translation>
     </message>
@@ -646,7 +646,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+202"/>
+        <location filename="info.cpp" line="+203"/>
         <source>Command executed: %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -664,7 +664,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+110"/>
+        <location filename="infofield.cpp" line="+113"/>
         <source>Size</source>
         <translation type="unfinished"></translation>
     </message>
@@ -689,12 +689,17 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+17"/>
+        <location line="+5"/>
+        <source>Overall speed (all acquisitions)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+13"/>
         <source>bytes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-15"/>
+        <location line="-16"/>
         <source>Hash calculation</source>
         <translation type="unfinished"></translation>
     </message>
@@ -721,7 +726,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+88"/>
+        <location line="+91"/>
         <location line="+9"/>
         <location line="+6"/>
         <source>on</source>
@@ -737,7 +742,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-114"/>
+        <location line="-117"/>
         <source>Additional state info</source>
         <translation type="unfinished"></translation>
     </message>
@@ -767,7 +772,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+399"/>
+        <location filename="device.cpp" line="+401"/>
         <source>Local device</source>
         <translation type="unfinished"></translation>
     </message>
@@ -777,7 +782,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+60"/>
+        <location line="+66"/>
         <source>Cleanup</source>
         <translation type="unfinished"></translation>
     </message>
@@ -787,12 +792,12 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-355"/>
+        <location line="-362"/>
         <source>Aborted by user</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+292"/>
+        <location filename="mainwindow.cpp" line="+293"/>
         <source>&amp;Rescan</source>
         <translation type="unfinished"></translation>
     </message>
@@ -843,7 +848,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+160"/>
+        <location line="+190"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -870,7 +875,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
 Version: %1
-Compilation timestamp: %2
+Version timestamp: %2
 Compiled with gcc %3
 Linked with libguytools %4
 Linked with libewf %5 %6</source>
@@ -881,10 +886,17 @@ Linked with libewf %5 %6</source>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
 Version: %1
-Compilation timestamp: %2
+Version timestamp: %2
 Compiled with gcc %3
 Linked with libguytools %4
 Compiled without libewf support</source>
+        <oldsource>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Compiled without libewf support</oldsource>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -894,7 +906,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="device.cpp" line="+352"/>
+        <location filename="device.cpp" line="+359"/>
         <source>Device disconnected, acquisition paused</source>
         <translation type="unfinished"></translation>
     </message>
@@ -922,7 +934,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-462"/>
+        <location filename="mainwindow.cpp" line="-492"/>
         <source>Rescan devices and update table</source>
         <translation type="unfinished"></translation>
     </message>
@@ -965,17 +977,17 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-168"/>
+        <location filename="device.cpp" line="-174"/>
         <source>Used in clone operation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+15"/>
+        <location line="+17"/>
         <source>Aborting...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+163"/>
+        <location line="+167"/>
         <source>none</source>
         <comment>column hidden areas</comment>
         <translation type="unfinished"></translation>
@@ -992,15 +1004,20 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+416"/>
+        <location line="+446"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-468"/>
+        <location filename="device.cpp" line="-475"/>
         <source>Acquisition start failure</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Device (re)moved</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+1"/>
         <source>Device read error</source>
@@ -1052,7 +1069,17 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+278"/>
+        <location line="+281"/>
+        <source>Launched, device disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Launched</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>Running</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1062,7 +1089,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+53"/>
+        <location line="+54"/>
         <location line="+26"/>
         <source>Verified &amp; ok</source>
         <comment>Status column</comment>
@@ -1120,7 +1147,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-395"/>
+        <location line="-401"/>
         <source>Too many bad sectors</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1173,7 +1200,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+579"/>
+        <location line="+581"/>
         <source>Finished successfully</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1249,7 +1276,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-642"/>
+        <location line="-644"/>
         <source>Linux device:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1261,7 +1288,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+643"/>
+        <location line="+645"/>
         <location line="+24"/>
         <source>Acquisition started:: %1</source>
         <comment>Info file</comment>
@@ -1300,19 +1327,13 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-626"/>
+        <location line="-628"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+1"/>
-        <source>Compilation timestamp:: %1</source>
-        <comment>Info file</comment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location line="+1"/>
+        <location line="+2"/>
         <source>Compiled with:: %1 %2</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1324,13 +1345,13 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+683"/>
+        <location line="+685"/>
         <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-639"/>
+        <location line="-641"/>
         <source>Source verification:: on</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1342,7 +1363,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+507"/>
+        <location line="+509"/>
         <source>(during source verification)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1354,13 +1375,19 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-584"/>
+        <location line="-586"/>
         <source>Image path and file name:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-42"/>
+        <location line="-47"/>
+        <source>Version timestamp:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+5"/>
         <source>(not used as Guymager is configured to use its own EWF module)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1415,7 +1442,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+516"/>
+        <location line="+518"/>
         <source>Aborted, too many bad sectors (&gt; %1)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1483,7 +1510,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-844"/>
+        <location line="-846"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
@@ -1536,7 +1563,7 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+866"/>
+        <location line="+868"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1552,12 +1579,12 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-881"/>
+        <location line="-883"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+739"/>
+        <location line="+741"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1574,13 +1601,13 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-672"/>
+        <location line="-674"/>
         <source>Hash calculation:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+521"/>
+        <location line="+523"/>
         <source>Aborted because of source read error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1610,13 +1637,13 @@ Compiled without libewf support</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-607"/>
+        <location line="-609"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+725"/>
+        <location line="+727"/>
         <source>Acquisition/verification aborted - file list may be incomplete</source>
         <translation type="unfinished"></translation>
     </message>
