@@ -9,7 +9,8 @@
 //  Module:         Hash wrapper functions for uniform hash interface
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -61,7 +62,7 @@ APIRET HashMD5Init (t_pHashContextMD5 pContext)
    return NO_ERROR;
 }
 
-APIRET HashMD5Append (t_pHashContextMD5 pContext, const void *pData, int DataLen)
+APIRET HashMD5Append (t_pHashContextMD5 pContext, const void *pData, unsigned int DataLen)
 {
    #ifdef USE_MD5_FROM_OPENSSL
       (void) MD5_Update (pContext, pData, (unsigned long) DataLen); // Same remark as for MD5_Init
@@ -124,7 +125,7 @@ APIRET HashSHA1Init (t_pHashContextSHA1 pContext)
    return NO_ERROR;
 }
 
-APIRET HashSHA1Append (t_pHashContextSHA1 pContext, void *pData, int DataLen)
+APIRET HashSHA1Append (t_pHashContextSHA1 pContext, void *pData, unsigned int DataLen)
 {
    #ifdef USE_SHA1_FROM_OPENSSL
       (void) SHA1_Update (pContext, pData, (unsigned long) DataLen);
@@ -187,7 +188,7 @@ APIRET HashSHA256Init (t_pHashContextSHA256 pContext)
    return NO_ERROR;
 }
 
-APIRET HashSHA256Append (t_pHashContextSHA256 pContext, void *pData, int DataLen)
+APIRET HashSHA256Append (t_pHashContextSHA256 pContext, void *pData, unsigned int DataLen)
 {
    #ifdef USE_SHA256_FROM_OPENSSL
       (void) SHA256_Update (pContext, pData, (unsigned long) DataLen);
