@@ -9,7 +9,8 @@
 //  Module:         Hash wrapper functions for uniform hash interface
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -27,10 +28,10 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#ifndef __HASH_H__
-#define __HASH_H__
+#ifndef HASH_H
+#define HASH_H
 
-#ifndef __COMMON_H__
+#ifndef COMMON_H
    #include "common.h"
 #endif
 
@@ -90,21 +91,21 @@ typedef t_HashSHA256Digest const * t_pcHashSHA256Digest;
 
 APIRET HashMD5Clear     (t_pHashContextMD5 pContext);
 APIRET HashMD5Init      (t_pHashContextMD5 pContext);
-APIRET HashMD5Append    (t_pHashContextMD5 pContext, const void *pData, int DataLen);
+APIRET HashMD5Append    (t_pHashContextMD5 pContext, const void *pData, unsigned int DataLen);
 APIRET HashMD5Digest    (t_pHashContextMD5 pContext, t_pHashMD5Digest pDigest);
 APIRET HashMD5DigestStr (t_pHashMD5Digest pDigest, QString &Str);
 bool   HashMD5Match     (t_pcHashMD5Digest pDigest1, t_pcHashMD5Digest pDigest2);
 
 APIRET HashSHA1Clear     (t_pHashContextSHA1 pContext);
 APIRET HashSHA1Init      (t_pHashContextSHA1 pContext);
-APIRET HashSHA1Append    (t_pHashContextSHA1 pContext, void *pData, int DataLen);
+APIRET HashSHA1Append    (t_pHashContextSHA1 pContext, void *pData, unsigned int DataLen);
 APIRET HashSHA1Digest    (t_pHashContextSHA1 pContext, t_pHashSHA1Digest pDigest);
 APIRET HashSHA1DigestStr (t_pHashSHA1Digest pDigest, QString &Str);
 bool   HashSHA1Match     (t_pcHashSHA1Digest pDigest1, t_pcHashSHA1Digest pDigest2);
 
 APIRET HashSHA256Clear     (t_pHashContextSHA256 pContext);
 APIRET HashSHA256Init      (t_pHashContextSHA256 pContext);
-APIRET HashSHA256Append    (t_pHashContextSHA256 pContext, void *pData, int DataLen);
+APIRET HashSHA256Append    (t_pHashContextSHA256 pContext, void *pData, unsigned int DataLen);
 APIRET HashSHA256Digest    (t_pHashContextSHA256 pContext, t_pHashSHA256Digest pDigest);
 APIRET HashSHA256DigestStr (t_pHashSHA256Digest pDigest, QString &Str);
 bool   HashSHA256Match     (t_pcHashSHA256Digest pDigest1, t_pcHashSHA256Digest pDigest2);
