@@ -11,7 +11,8 @@
 //                  deinitialisation.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -77,9 +78,9 @@
 //              Constants
 // ------------------------------------
 
-static const int MAIN_MAX_ERROR_CODES        = 1000;
-static const int MAIN_SHOW_SPLASH_TIME_EVENT =  300;  // ms
-static const int MAIN_PROCESSEVENTS_MAXTIME  = 1000;
+static const uint MAIN_MAX_ERROR_CODES         = 1000;
+static const uint  MAIN_SHOW_SPLASH_TIME_EVENT =  300;  // ms
+static const uint  MAIN_PROCESSEVENTS_MAXTIME  = 1000;
 
 enum
 {
@@ -133,6 +134,11 @@ static t_MainLocal MainLocal;
 
 int t_MainSystemSignalForwarder::oArrFileDescHup[2];
 
+#pragma GCC diagnostic push
+#ifdef Q_CREATOR_RUN
+#pragma GCC diagnostic ignored "-Wdisabled-macro-expansion"
+#endif
+
 t_MainSystemSignalForwarder::t_MainSystemSignalForwarder (QObject *parent)
    :QObject(parent)
 {
@@ -148,10 +154,11 @@ t_MainSystemSignalForwarder::t_MainSystemSignalForwarder (QObject *parent)
    SigActionHup.sa_handler = SignalHandlerHup;
    SigActionHup.sa_flags   = 0;
    SigActionHup.sa_flags  |= SA_RESTART;
-   if (sigaction(SIGHUP, &SigActionHup, 0))
+   if (sigaction(SIGHUP, &SigActionHup, nullptr))
       CHK_EXIT (ERROR_MAIN_SIGACTION_FAILED)
 }      
-      
+#pragma GCC diagnostic pop
+
 t_MainSystemSignalForwarder::~t_MainSystemSignalForwarder ()
 {
 }
@@ -248,7 +255,7 @@ static void MainSignalHandler (int Signal)
 }
 
 // MainSignalLog: Called by ToolSignal for doing log output
-static void MainSignalLog (bool Error, int /*ThreadNr*/, const char *pFileName, const char *pFunction, int LineNr, const char *pFormat, va_list pArguments)
+static void MainSignalLog (bool Error, unsigned long long /*ThreadNr*/, const char *pFileName, const char *pFunction, int LineNr, const char *pFormat, va_list pArguments)
 {
    t_Log::t_Level Level;
 
@@ -299,8 +306,8 @@ static void MainCfgLog (t_pcchar pFileName, t_pcchar pFunction, t_int LineNr, t_
    va_list     pArgumentsCopy;
 
    if (!ConsoleLog)
-        ConsoleLog = (strstr (pFormat, "Configuration error"       ) != NULL);
-   else ConsoleLog = (strstr (pFormat, "TOOLCFG_ERROR_CONFIG_ERROR") == NULL);
+        ConsoleLog = (strstr (pFormat, "Configuration error"       ) != nullptr);
+   else ConsoleLog = (strstr (pFormat, "TOOLCFG_ERROR_CONFIG_ERROR") == nullptr);
 
    __va_copy (pArgumentsCopy, pArguments);
    if (ConsoleLog)
@@ -319,14 +326,14 @@ static void MainCfgLog (t_pcchar pFileName, t_pcchar pFunction, t_int LineNr, t_
 class t_MainTranslator : public QTranslator    // Has been extended initially to support configuration file driven
 {                                              // translation of text UserField, might be used for others as well.
    public:
-      t_MainTranslator (QObject *pParent=0) : QTranslator (pParent) {} ;
+      t_MainTranslator (QObject *pParent=nullptr) : QTranslator (pParent) {}
 
       void Insert (const QString &Source, const QString &Translation)
       {
          (void) oDict.insert (Source, Translation);
       }
 
-      QString translate (const char *pContext, const char *pSourceText, const char *pDisambiguation = 0, int n = -1) const
+      QString translate (const char *pContext, const char *pSourceText, const char *pDisambiguation = nullptr, int n = -1) const
       {
          QString Source(pSourceText);
 
@@ -368,7 +375,7 @@ static void ShowSplashText (QSplashScreen *pSplashScreen, QString Text)
 
 static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
 {
-   QSplashScreen *pSplashScreen = NULL;
+   QSplashScreen *pSplashScreen = nullptr;
    QPixmap       *pSplashPixmap;
    QString         Uname;
    const char    *pLogFileName;
@@ -410,7 +417,8 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    CHK_EXIT (Err)
    LOG_INFO ("=================================================== Starting GUYMAGER ===================================================")
    LOG_INFO ("Version: %s", pCompileInfoVersion)
-   LOG_INFO ("Compile timestamp: %s", pCompileInfoTimestamp)
+   LOG_INFO ("Version timestamp: %s", pCompileInfoTimestampChangelog)
+   LOG_INFO ("Compile timestamp: %s", pCompileInfoTimestampBuild)
    CHK_EXIT (ToolSysInfoUname (Uname))
    LOG_INFO ("System: %s", QSTR_TO_PSZ(Uname))
 
@@ -443,9 +451,9 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    int      AdjustedArgc;
    char **ppAdjustedArgv;
 
-   AdjustedArgc = QApplication::arguments().count();                  // Ask Qt for command line argument list; the list returned already has been
-   ppAdjustedArgv = (char**) malloc (AdjustedArgc * sizeof(char *));  // cleaned so that Qt specific command line parameters (such as -style=plastique)
-   for (int i=0; i<AdjustedArgc; i++)                                 // no longer figure in it.
+   AdjustedArgc = QApplication::arguments().count();                          // Ask Qt for command line argument list; the list returned already has been
+   ppAdjustedArgv = (char**) malloc ((size_t)AdjustedArgc * sizeof(char *));  // cleaned so that Qt specific command line parameters (such as -style=plastique)
+   for (int i=0; i<AdjustedArgc; i++)                                         // no longer figure in it.
       ppAdjustedArgv[i] = strdup (QSTR_TO_PSZ(QApplication::arguments()[i]));
 
    CHK (ToolCfgUseAdjustedCommandLine (AdjustedArgc, ppAdjustedArgv))
@@ -578,10 +586,10 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
       if (CONFIG(CheckRootRights))
       {
          LOG_INFO ("Running with non-root rights, asking user...")
-         Button = t_MessageBox::question (NULL, QObject::tr ("Missing root rights", "Dialog title"),
-                                                QObject::tr ("Guymager needs to be started with root rights in order to perform acquisitions. "
-                                                             "You are not root and thus won't be able to acquire devices.\nContinue anyway?"),
-                                                              QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
+         Button = t_MessageBox::question (nullptr, QObject::tr ("Missing root rights", "Dialog title"),
+                                                   QObject::tr ("Guymager needs to be started with root rights in order to perform acquisitions. "
+                                                                "You are not root and thus won't be able to acquire devices.\nContinue anyway?"),
+                                                                 QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
          if (Button == QMessageBox::Yes)
          {
             LOG_INFO ("User continues anyway")
@@ -604,7 +612,7 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    MainLocal.pSystemSignalForwarder = new t_MainSystemSignalForwarder();
 
    if (CONFIG (SignalHandling))
-      CHK_EXIT (ToolSignalInit (MainSignalLog, MainSignalHandler, NULL))
+      CHK_EXIT (ToolSignalInit (MainSignalLog, MainSignalHandler, nullptr))
 
    // Critical initialisation phase done, CFG, ERROR and LOG operational now
    // ----------------------------------------------------------------------
@@ -630,7 +638,7 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    
    #if (ENABLE_LIBEWF)
       #if (LIBEWF_VERSION >= 20130416)
-         libewf_notify_set_stream  (stderr, NULL);
+         libewf_notify_set_stream  (stderr, nullptr);
          libewf_notify_set_verbose (CONFIG (VerboseLibewf) ? 1 : 0);
       #else
          libewf_set_notify_values (stderr, CONFIG (VerboseLibewf) ? 1 : 0);
@@ -647,6 +655,7 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
 
    MainLocal.pMainWindow = new t_MainWindow (MainLocal.pDeviceList);
    CHK_QT_EXIT (MainLocal.pApp->connect(MainLocal.pMainWindow, SIGNAL(SignalAutoExit(void)), MainLocal.pApp, SLOT(quit(void))))
+
    CHK (MainWindowAdjustSize (MainLocal.pMainWindow))
 
    if (pSplashScreen)
@@ -668,9 +677,9 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    delete MainLocal.pMainWindow;
    delete MainLocal.pDeviceList;
    delete MainLocal.pNumberLocale;
-   MainLocal.pMainWindow   = NULL;
-   MainLocal.pDeviceList   = NULL;
-   MainLocal.pNumberLocale = NULL;
+   MainLocal.pMainWindow   = nullptr;
+   MainLocal.pDeviceList   = nullptr;
+   MainLocal.pNumberLocale = nullptr;
 
    CHK (AewfDeInit  ())
    CHK (AaffDeInit  ())
@@ -707,19 +716,19 @@ int main (int argc, char *argv[])
 {
    APIRET        rc;
    int           i;
-   int           Len=0;
+   size_t        Len=0;
    int           ExitCode = EXIT_NO_ERROR;
    bool          AutoExit;
    const char  *pFilenameMallocTracing;
 
    pFilenameMallocTracing = getenv (MAIN_ENVVAR_MALLOC_TRACE);
-   if (pFilenameMallocTracing != NULL)  // Switch on memory allocation tracing,
+   if (pFilenameMallocTracing != nullptr)  // Switch on memory allocation tracing,
    {
       printf ("\nSwitching malloc tracing on, output file is %s", pFilenameMallocTracing);
       mtrace();                                    // see tracing functionality in GNU C lib
    }
-   setbuf(stdout, NULL);
-   setbuf(stderr, NULL);
+   setbuf(stdout, nullptr);
+   setbuf(stderr, nullptr);
    setlocale (LC_ALL, "");
 
    memset (&MainLocal, 0, sizeof(MainLocal));
@@ -746,7 +755,8 @@ int main (int argc, char *argv[])
    free (MainLocal.pCommandLine);
 
    printf ("\n");
-   if (rc == TOOLCFG_ERROR_CONFIG_ERROR)
+   if ((rc == TOOLCFG_ERROR_CONFIG_ERROR) ||
+       (rc == ERROR_CFG_INCOHERENCY_DETECTED))
         printf ("Error in configuration file. See log file for details.\n");
    else CHK_EXIT (rc)
 
