@@ -9,7 +9,8 @@
 //  Module:         Main
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -27,11 +28,15 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-APIRET        MainPocessEvents     (void);
-APIRET        MainGetCommandLine   (char **ppCommandLine);
-QLocale      *MainGetpNumberLocale (void);
+#ifndef MAIN_H
+#define MAIN_H
 
-#ifdef __DEVICE_H__
+APIRET   MainPocessEvents     (void);
+APIRET   MainGetCommandLine   (char **ppCommandLine);
+QLocale *MainGetpNumberLocale (void);
+
+#ifdef DEVICE_H
    t_pDeviceList MainGetDeviceList (void);
 #endif
 
+#endif
