@@ -10,7 +10,8 @@
 //                  widget
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -88,25 +89,25 @@ static t_MainWindowColumn MainWindowColumnArr[] =
    { MAINWINDOW_COLUMN_CurrentSpeed  , t_Device::GetCurrentSpeed  , t_ItemDelegate::DISPLAYTYPE_STANDARD },
    { MAINWINDOW_COLUMN_UserField     , t_Device::GetUserField     , t_ItemDelegate::DISPLAYTYPE_STANDARD },
    { MAINWINDOW_COLUMN_Examiner      , t_Device::GetExaminer      , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { NULL                            , NULL                       , 0                                    }
+   { nullptr                         , nullptr                    , 0                                    }
 };
 
 t_pMainWindowColumn MainWindowGetColumn (const char *pName)
 {
    t_pMainWindowColumn pCol;
 
-   for (pCol=&MainWindowColumnArr[0]; pCol->pName != NULL; pCol++)
+   for (pCol=&MainWindowColumnArr[0]; pCol->pName != nullptr; pCol++)
       if (strcasecmp (pCol->pName, pName) == 0)
          break;
-   if (pCol->pName == NULL)
-      pCol = NULL;
+   if (pCol->pName == nullptr)
+      pCol = nullptr;
 
    return pCol;
 }
 
 bool MainWindowColumnExists (const char *pName)
 {
-   return (MainWindowGetColumn (pName) != NULL);
+   return (MainWindowGetColumn (pName) != nullptr);
 }
 
 t_DeviceListModel::t_DeviceListModel ()
@@ -131,7 +132,7 @@ t_DeviceListModel::t_DeviceListModel (t_pDeviceList pDeviceList)
       if (pColCfg->ShowInMainTable)
       {
          pColDef = MainWindowGetColumn (pColCfg->Name);
-         if (pColDef == NULL)
+         if (pColDef == nullptr)
             CHK_EXIT(ERROR_MAINWINDOW_UNKNOWN_COLUMN)
 
          ColAssoc.Name        = tr(pColCfg->Name);
@@ -367,7 +368,7 @@ t_MainWindow::t_MainWindow (t_pDeviceList pDeviceList, QWidget *pParent, Qt::Win
    pOwn->pProxyModel->setSourceModel (pOwn->pDeviceListModel);
    pOwn->pTable     ->setModel       (pOwn->pProxyModel);
 
-   pOwn->pInfoField = new t_InfoField (pOwn->pCentralWidget);
+   pOwn->pInfoField = new t_InfoField (pOwn->pCentralWidget, pDeviceList);
 
    pLayout->addWidget (pOwn->pTable);
    pLayout->addWidget (pOwn->pInfoField);
@@ -452,7 +453,7 @@ void t_MainWindow::SlotAddSpecialDevice (void)
    QFileInfo    FileInfo ;
    t_pDevice   pDevice;
    t_pDevice   pDeviceFound;
-   FILE       *pFile = NULL;
+   FILE       *pFile = nullptr;
    bool         Error;
    qint64       Size;
 
@@ -468,7 +469,7 @@ void t_MainWindow::SlotAddSpecialDevice (void)
       {
          LOG_INFO ("Qt thinks the file size for %s is %lld, trying seek to get it", QSTR_TO_PSZ(FileName), Size)
          pFile = fopen64 (QSTR_TO_PSZ(FileName), "r");
-         Error = (pFile == NULL);
+         Error = (pFile == nullptr);
          if (!Error)
             Error = (fseeko64 (pFile, 0, SEEK_END) != 0);
          if (!Error)
@@ -524,7 +525,7 @@ void t_MainWindow::SlotScanStarted (void)
 
 
 // SlotScanFinished provides us with the new device list. Now, our current device list needs to be updated. The rules are:
-//  (1) For devices, who are in both lists:
+//  (1) For devices, that are in both lists:
 //        Set the state of the device in the current list to Connected. Thus, devices that were temporarly disconnected
 //        will become connected again.
 //  (2) For devices, that only exist in the current list (but no longer in the new list):
@@ -535,7 +536,7 @@ void t_MainWindow::SlotScanStarted (void)
 //        c) Do nothing if there's a verification running where only the image is verified
 //  (3) For devices, that only exist in the new list:
 //        Add to the current list
-// Remark: Is it quite tricky to compare the devices from both lists, as there devices without a serial number. See
+// Remark: Is it quite tricky to compare the devices from both lists if there are devices without a serial number. See
 // t_DeviceList::MatchDevice for details.
 
 void t_MainWindow::SlotScanFinished (t_pDeviceList pNewDeviceList)
@@ -550,10 +551,10 @@ void t_MainWindow::SlotScanFinished (t_pDeviceList pNewDeviceList)
    for (i=0; i<pDeviceList->count(); i++)
    {
       pDev = pDeviceList->at (i);
-      if (pDev->SpecialDevice)
-           pDev->Checked = true;   // Checked is used to remember which devices we have seen and which ones not. Treat
-      else pDev->Checked = false;  // special devices as already seen, thus, they are not going to be removed from the list.
-      pDev->AddedNow=false;
+      pDev->Checked = pDev->SpecialDevice; // Checked is used to remember which devices we have seen and which ones not. Treat 
+      pDev->AddedNow=false;                // special devices as already seen, thus, they are not going to be removed from the list.
+      if ((pDev->SpecialDevice) && (pDev->GetState() == t_Device::Launch)) // For special devices there is not such thing as devices changing
+         pDev->SetState (t_Device::Acquire);                               // paths, so we change their state from Launch the Acquire here.
    }
 
    for (i=0; i<pNewDeviceList->count(); i++)
@@ -579,17 +580,41 @@ void t_MainWindow::SlotScanFinished (t_pDeviceList pNewDeviceList)
       if (!NewDevice)
       {
          pDev->Checked = true;
-         pDev->NativePath  = pNewDev->NativePath;     // The device might have been connected to a
-         pDev->ByPath      = pNewDev->ByPath;         // different port.
+         pDev->NativePath  = pNewDev->NativePath;        // The device might have been connected to a
+         pDev->ByPath      = pNewDev->ByPath;            // different port.
          pDev->Interface   = pNewDev->Interface;
-         if ((pDev->GetState() == t_Device::AcquirePaused) ||
-             (pDev->GetState() == t_Device::VerifyPaused))
+         if (pDev->LinuxDevice != pNewDev->LinuxDevice)  // Linux may choose a new path when reconnecting the device
          {
-            LOG_INFO ("Switching %s to connected again", QSTR_TO_PSZ(pNewDev->LinuxDevice))
-            pDev->LinuxDevice = pNewDev->LinuxDevice;    // Linux may choose a new path when reconnecting the device
-            if (pDev->GetState() == t_Device::AcquirePaused)  // (1)
-                 pDev->SetState (t_Device::Acquire);
-            else pDev->SetState (t_Device::Verify );
+            LOG_INFO ("Device previously accessible under %s moved to %s", QSTR_TO_PSZ(pDev->LinuxDevice), QSTR_TO_PSZ(pNewDev->LinuxDevice))
+         }
+
+         if ((pDev->GetState() == t_Device::Launch) ||
+             (pDev->GetState() == t_Device::LaunchPaused))
+         {
+            if ((pDev->LinuxDevice != pNewDev->LinuxDevice) || (pDev->GetState() == t_Device::LaunchPaused))
+            {
+               LOG_INFO ("Just launched acquisition of %s: Device changed its path to %s, aborting.", QSTR_TO_PSZ (pDev->LinuxDevice), QSTR_TO_PSZ (pNewDev->LinuxDevice))
+               pDev->Error.Set (t_Device::t_Error::DeviceMovedOnLaunch);
+            }
+            else
+            {
+               LOG_INFO ("Acquisition launch of %s confirmed", QSTR_TO_PSZ(pDev->LinuxDevice))
+               pDev->SetState (t_Device::Acquire);
+            }
+         }
+         else
+         {
+            if (pDev->GetState() == t_Device::AcquirePaused)
+            {
+               LOG_INFO ("Continuing acquisition of %s", QSTR_TO_PSZ(pDev->LinuxDevice))
+               pDev->SetState (t_Device::Acquire);          // (1)
+            }
+            else if (pDev->GetState() == t_Device::VerifyPaused)
+            {
+               LOG_INFO ("Continuing verification of %s", QSTR_TO_PSZ(pDev->LinuxDevice))
+               pDev->SetState (t_Device::Verify );          // (1)
+            }
+            pDev->LinuxDevice = pNewDev->LinuxDevice;
          }
       }
       else
@@ -616,6 +641,10 @@ void t_MainWindow::SlotScanFinished (t_pDeviceList pNewDeviceList)
                                           break;
             case t_Device::AcquirePaused: break;
             case t_Device::VerifyPaused : break;
+            case t_Device::Launch       :
+            case t_Device::LaunchPaused : LOG_INFO ("Just launched acquisition of %s: Device no longer available, aborting.", QSTR_TO_PSZ (pDev->LinuxDevice))
+                                          pDev->Error.Set (t_Device::t_Error::DeviceMovedOnLaunch);
+                                          break;
             default                     : pDeviceList->removeAt (i--);                         // (2a)
                                           delete pDev;
          }
@@ -643,8 +672,10 @@ void t_MainWindow::closeEvent (QCloseEvent *pEvent)
       AcquisitionsActive = (pDevice->GetState() == t_Device::Acquire)       ||
                            (pDevice->GetState() == t_Device::Verify )       ||
                            (pDevice->GetState() == t_Device::Cleanup)       ||
+                           (pDevice->GetState() == t_Device::Launch)        ||
+                           (pDevice->GetState() == t_Device::LaunchPaused)  ||
                            (pDevice->GetState() == t_Device::AcquirePaused) ||
-                           (pDevice->GetState() == t_Device::VerifyPaused );
+                           (pDevice->GetState() == t_Device::VerifyPaused);
    }
 
    if (AcquisitionsActive)
@@ -721,16 +752,16 @@ void t_MainWindow::SlotAboutGuymager (void)
          EwfRemark = tr("(not used as Guymager currently is configured to use its own EWF module)");
    #endif
 
-   #if (ENABLE_LIBEWF)  // Do not factorise the code below, as Qt Linguist will problems otherwise
+   #if (ENABLE_LIBEWF)  // Do not factorise the code below, as Qt Linguist will have problems otherwise
       QMessageBox::about(this, tr("About GUYMAGER", "Dialog title"),
                                tr("GUYMAGER is a Linux-based forensic imaging tool\n\n"
                                   "Version: %1\n"
-                                  "Compilation timestamp: %2\n"
+                                  "Version timestamp: %2\n"
                                   "Compiled with gcc %3\n"
                                   "Linked with libguytools %4\n"
                                   "Linked with libewf %5 %6")
                                   .arg(pCompileInfoVersion)
-                                  .arg(pCompileInfoTimestamp)
+                                  .arg(pCompileInfoTimestampChangelog)
                                   .arg(__VERSION__)
                                   .arg(pLibGuyToolsVersionInstalled)
                                   .arg(pLibEwfVersionInstalled) .arg(EwfRemark)
@@ -739,12 +770,12 @@ void t_MainWindow::SlotAboutGuymager (void)
       QMessageBox::about(this, tr("About GUYMAGER", "Dialog title"),
                                tr("GUYMAGER is a Linux-based forensic imaging tool\n\n"
                                   "Version: %1\n"
-                                  "Compilation timestamp: %2\n"
+                                  "Version timestamp: %2\n"
                                   "Compiled with gcc %3\n"
                                   "Linked with libguytools %4\n"
                                   "Compiled without libewf support")
                                   .arg(pCompileInfoVersion)
-                                  .arg(pCompileInfoTimestamp)
+                                  .arg(pCompileInfoTimestampChangelog)
                                   .arg(__VERSION__)
                                   .arg(pLibGuyToolsVersionInstalled)
                                   );
