@@ -9,7 +9,8 @@
 //  Module:         Different Qt utility functions
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -49,8 +50,8 @@ const QColor QtUtilColorDefault; // Accessible externally as well, see qtutil.h.
                                  // QColor default construtor) and is interpreted in the QtUtil functions as the default color (gray for
                                  // a button background, for instance; see QtUtilSetButtonColor for an example on how it is used)
 
-static const float QTUTIL_GEOMETRY_MAXFACTOR_X = 0.95;
-static const float QTUTIL_GEOMETRY_MAXFACTOR_Y = 0.95;
+static const float QTUTIL_GEOMETRY_MAXFACTOR_X = 0.95f;
+static const float QTUTIL_GEOMETRY_MAXFACTOR_Y = 0.95f;
 
 static const int QTUTIL_WAIT_PROCESS_MAX    = 60000;
 
@@ -85,10 +86,10 @@ APIRET QtUtilSetGeometryCentered (QWidget *pWidget, int Dx, int Dy)
    Dy = GETMIN (Dy, (int)(ScreenDy * QTUTIL_GEOMETRY_MAXFACTOR_Y)); // than the screen minus a certain border.
 
    if (pWidget->windowFlags() & Qt::Dialog)
-        pParent = NULL;
+        pParent = nullptr;
    else pParent = pWidget->parentWidget();
 
-   if (pParent == NULL)
+   if (pParent == nullptr)
    {
       X = (ScreenDx - Dx) / 2;
       Y = (ScreenDy - Dy) / 2;
@@ -188,7 +189,7 @@ APIRET QtUtilGetNumStrWidth (QPainter const *pPainter, QFont const *pFont, int I
    Str.sprintf ("%0*.*f", Digits, FrcLen, 0.0);
    Str.replace ('.', ',');
 
-   CHK (QtUtilGetTextSize (pPainter, pFont, Str, pDx, NULL))
+   CHK (QtUtilGetTextSize (pPainter, pFont, Str, pDx, nullptr))
 
    return NO_ERROR;
 }
@@ -199,7 +200,7 @@ APIRET QtUtilGetAvgStrWidth (QPainter const *pPainter, QFont const *pFont, int C
    int     AvgCharWidth;
 
    AvgChar = "N";    // Let it be the average character...
-   CHK (QtUtilGetTextSize (pPainter, pFont, AvgChar, &AvgCharWidth, NULL))
+   CHK (QtUtilGetTextSize (pPainter, pFont, AvgChar, &AvgCharWidth, nullptr))
    *pAvgWidth = Chars * AvgCharWidth;
 
    return NO_ERROR;
@@ -296,14 +297,14 @@ APIRET QtUtilAdjustDefaults (QLayout *pLayout, bool TopLevelLayout)
    {
       pChildWidget = pLayoutItem->widget();
       pChildLayout = pLayoutItem->layout();
-      if (pChildWidget != NULL)
+      if (pChildWidget != nullptr)
       {
 //         if      (pChildWidget->inherits ("QPushButton")) CHK (QtUtilAdjustPushButton ((QPushButton*) pChildWidget))
 //         else if (pChildWidget->inherits ("QLabel"     )) CHK (QtUtilAdjustLabel      ((QLabel     *) pChildWidget))
          if      (pChildWidget->inherits ("QPushButton")) CHK (QtUtilAdjustPushButton (dynamic_cast<QPushButton*>(pChildWidget)))
          else if (pChildWidget->inherits ("QLabel"     )) CHK (QtUtilAdjustLabel      (dynamic_cast<QLabel     *>(pChildWidget)))
       }
-      else if (pChildLayout != NULL)
+      else if (pChildLayout != nullptr)
       {
          CHK (QtUtilAdjustDefaults (pChildLayout, false)) // recursive call for processing sub-layouts
       }
@@ -408,7 +409,7 @@ APIRET QtUtilProcessCommand (const QString &Command, QString *pStandardOutput)
 //      close (PipeArr[STDOUT_FILENO]);                      // Close unused side of pipe (in side)
 //
 //      pStream = fdopen (PipeArr[STDIN_FILENO], "r");
-//      if (pStream == NULL)
+//      if (pStream == nullptr)
 //         CHK (ERROR_QTUTIL_STREAM_OPEN_FAILED)
 //
 //      while ((Ch = fgetc (pStream)) != EOF)
@@ -422,7 +423,7 @@ APIRET QtUtilProcessCommand (const QString &Command, QString *pStandardOutput)
 //      dup2  (commpipe[STDOUT_FILENO],STDOUT_FILENO);       // Replace stdout with out side of the pipe
 //      close (commpipe[STDIN_FILENO ]);                     // Close unused side of pipe (out side)
 //
-//      execl ("/bin/bash", "/bin/bash", "--noprofile", "--norc", "--posix", "-c", QSTR_TO_PSZ(Command), NULL);    // Replace the child fork with a new process
+//      execl ("/bin/bash", "/bin/bash", "--noprofile", "--norc", "--posix", "-c", QSTR_TO_PSZ(Command), nullptr);    // Replace the child fork with a new process
 //      _exit (1);
 //   }
 //
