@@ -9,7 +9,8 @@
 //  Module:         The table widget (central widget of the application)
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -138,7 +139,7 @@ APIRET t_Table::GetDeviceUnderCursor (t_pDevice &pDevice)
    int         Row;
    int         Count;
 
-   pDevice = NULL;
+   pDevice = nullptr;
    QModelIndexList IndexList = selectionModel()->selectedRows();
    Count = IndexList.count();
    switch (Count)
@@ -307,9 +308,9 @@ APIRET t_Table::InfoAcquisitionStart (t_pAcquisition pAcquisition)
    CHK (pAcquisition->Info.WriteLn ())
    CHK (pAcquisition->Info.Title   (tr("Guymager", "Info file")))
    CHK (pAcquisition->Info.WriteLn ())
-   CHK (pAcquisition->Info.AddRow (tr("Version:: %1"              , "Info file") .arg(pCompileInfoVersion  )))
-   CHK (pAcquisition->Info.AddRow (tr("Compilation timestamp:: %1", "Info file") .arg(pCompileInfoTimestamp)))
-   CHK (pAcquisition->Info.AddRow (tr("Compiled with:: %1 %2"     , "Info file") .arg("gcc") .arg(__VERSION__)))
+   CHK (pAcquisition->Info.AddRow (tr("Version:: %1"          , "Info file") .arg(pCompileInfoVersion           )))
+   CHK (pAcquisition->Info.AddRow (tr("Version timestamp:: %1", "Info file") .arg(pCompileInfoTimestampChangelog)))
+   CHK (pAcquisition->Info.AddRow (tr("Compiled with:: %1 %2" , "Info file") .arg("gcc") .arg(__VERSION__)))
    #if (ENABLE_LIBEWF)
       QString EwfRemark;
       if (CONFIG(EwfFormat) == t_File::AEWF)
@@ -337,8 +338,8 @@ APIRET t_Table::InfoAcquisitionStart (t_pAcquisition pAcquisition)
    CHK (pAcquisition->Info.WriteLn ())
    CHK (pAcquisition->Info.Title   (tr("Acquisition", "Info file")))
    CHK (pAcquisition->Info.WriteLn ())
-   CHK (t_File::GetFormatDescription (pAcquisition->pDevice,        FormatDescription))
-   CHK (t_File::GetFormatExtension   (pAcquisition->pDevice, NULL, &FormatExtension))
+   CHK (t_File::GetFormatDescription (pAcquisition->pDevice,           FormatDescription))
+   CHK (t_File::GetFormatExtension   (pAcquisition->pDevice, nullptr, &FormatExtension))
    CHK (pAcquisition->Info.AddRow (tr("Linux device:: %1"    , "Info file").arg(pAcquisition->pDevice->LinuxDevice)))
    CHK (pAcquisition->Info.AddRow (tr("Device size:: %1 (%2)", "Info file").arg(pAcquisition->pDevice->Size) .arg(t_Device::GetSizeHuman(pAcquisition->pDevice).toString())))
    Str = tr("Format:: %1", "Info file") .arg(FormatDescription);
@@ -542,7 +543,7 @@ APIRET t_Table::StartAcquisition (t_pDevice pDevice)
    Clone = pDevice->Acquisition1.Clone;
    pOwn->SlowDownAcquisitions = true;
    LOG_INFO ("[%s] Starting acquisition (%s) (%llu bytes)", QSTR_TO_PSZ (pDevice->LinuxDevice), Clone ? "clone":"image", pDevice->Size)
-   CHK (t_File::GetFormatExtension  (pDevice->Acquisition1.Format, pDevice->Acquisition1.Clone, 0, NULL, &Format))
+   CHK (t_File::GetFormatExtension  (pDevice->Acquisition1.Format, pDevice->Acquisition1.Clone, 0, nullptr, &Format))
    if (Clone)
       Format = " (clone)";
    LOG_INFO ("[%s] Image %s%s%s", QSTR_TO_PSZ (pDevice->LinuxDevice), QSTR_TO_PSZ(pDevice->Acquisition1.ImagePath), QSTR_TO_PSZ(pDevice->Acquisition1.ImageFilename), QSTR_TO_PSZ(Format))
@@ -554,7 +555,7 @@ APIRET t_Table::StartAcquisition (t_pDevice pDevice)
       LOG_INFO ("[%s] Info  %s%s%s", QSTR_TO_PSZ (pDevice->LinuxDevice), QSTR_TO_PSZ(pDevice->Acquisition2.InfoPath ), QSTR_TO_PSZ(pDevice->Acquisition2.InfoFilename ), t_File::pExtensionInfo)
    }
    CHK (pDevice->SetMessage (QString()))
-   pDevice->SetState (t_Device::Acquire);
+   pDevice->SetState (t_Device::Launch);  // Starting with state "Launch", switching to "Acquire" as soon as a Rescan (triggered at end of this fn) has been done and device is still the same (see t_MainWindow::SlotScanFinished)
    pDevice->Error.Clear();
    pDevice->AbortCount          = 0;
    pDevice->DeleteAfterAbort    = false;
@@ -609,16 +610,16 @@ APIRET t_Table::StartAcquisition (t_pDevice pDevice)
    if (pDevice->Error.Abort())
       return rc;
 
-   if (pDevice->pThreadRead   != NULL) CHK_EXIT (ERROR_TABLE_THREADREAD_ALREADY_RUNNING )
-   if (pDevice->pThreadWrite1 != NULL) CHK_EXIT (ERROR_TABLE_THREADWRITE_ALREADY_RUNNING)
-   if (pDevice->pThreadWrite2 != NULL) CHK_EXIT (ERROR_TABLE_THREADWRITE_ALREADY_RUNNING)
-   if (pDevice->pThreadHash   != NULL) CHK_EXIT (ERROR_TABLE_THREADHASH_ALREADY_RUNNING )
+   if (pDevice->pThreadRead   != nullptr) CHK_EXIT (ERROR_TABLE_THREADREAD_ALREADY_RUNNING )
+   if (pDevice->pThreadWrite1 != nullptr) CHK_EXIT (ERROR_TABLE_THREADWRITE_ALREADY_RUNNING)
+   if (pDevice->pThreadWrite2 != nullptr) CHK_EXIT (ERROR_TABLE_THREADWRITE_ALREADY_RUNNING)
+   if (pDevice->pThreadHash   != nullptr) CHK_EXIT (ERROR_TABLE_THREADHASH_ALREADY_RUNNING )
    if (!pDevice->ThreadCompressList.isEmpty()) CHK_EXIT (ERROR_TABLE_THREADCOMPRESS_ALREADY_RUNNING)
-   if ((pDevice->pFifoRead        != NULL) ||
-       (pDevice->pFifoHashIn      != NULL) ||
-       (pDevice->pFifoHashOut     != NULL) ||
-       (pDevice->pFifoCompressIn  != NULL) ||
-       (pDevice->pFifoCompressOut != NULL))
+   if ((pDevice->pFifoRead        != nullptr) ||
+       (pDevice->pFifoHashIn      != nullptr) ||
+       (pDevice->pFifoHashOut     != nullptr) ||
+       (pDevice->pFifoCompressIn  != nullptr) ||
+       (pDevice->pFifoCompressOut != nullptr))
       CHK_EXIT (ERROR_TABLE_FIFO_EXISTS)
 
    // Create threads
@@ -727,6 +728,8 @@ APIRET t_Table::StartAcquisition (t_pDevice pDevice)
 
    pOwn->SlowDownAcquisitions = false;
 
+   pOwn->pMainWindow->SlotRescan(); // Rescan in order be sure that launched acquisition still refers to the correct device
+
    return NO_ERROR;
 }
 
@@ -788,12 +791,12 @@ APIRET t_Table::InfoAcquisitionBadSectors (t_pAcquisition pAcquisition, bool Ver
          First = false;
          if (From == To)
          {
-            CHK (pAcquisition->Info.Write ("%Lu", From))
+            CHK (pAcquisition->Info.Write ("%llu", From))
             LineEntries++;
          }
          else
          {
-            CHK (pAcquisition->Info.Write ("%Lu-%Lu", From, To))
+            CHK (pAcquisition->Info.Write ("%llu-%llu", From, To))
             LineEntries += 2;
          }
       }
@@ -1093,7 +1096,7 @@ static APIRET TableCallAcquisitionEndCommand (t_pDevice pDevice)
       QString Extension;
       QString StateStr;
 
-      CHK (t_File::GetFormatExtension (pDevice, NULL, &Extension))
+      CHK (t_File::GetFormatExtension (pDevice, nullptr, &Extension))
 
       switch (pDevice->GetState())
       {
@@ -1116,10 +1119,10 @@ static APIRET TableCallAcquisitionEndCommand (t_pDevice pDevice)
 
 APIRET t_Table::FinaliseThreadStructs (t_pDevice pDevice)
 {
-   if ((pDevice->pThreadRead   == NULL) &&        // t_Table::FinaliseThreadStructs is called upon every thread's end,
-       (pDevice->pThreadWrite1 == NULL) &&        // but its core only is executed after the last thread ended (as
-       (pDevice->pThreadWrite2 == NULL) &&        // we must not kill vital structures as long as any threads are
-       (pDevice->pThreadHash   == NULL) &&        // still running).
+   if ((pDevice->pThreadRead   == nullptr) &&        // t_Table::FinaliseThreadStructs is called upon every thread's end,
+       (pDevice->pThreadWrite1 == nullptr) &&        // but its core only is executed after the last thread ended (as
+       (pDevice->pThreadWrite2 == nullptr) &&        // we must not kill vital structures as long as any threads are
+       (pDevice->pThreadHash   == nullptr) &&        // still running).
        (pDevice->ThreadCompressList.isEmpty()))
    {
       pDevice->StopTimestamp = QDateTime::currentDateTime();
@@ -1145,13 +1148,13 @@ APIRET t_Table::FinaliseThreadStructs (t_pDevice pDevice)
          delete pDevice->pFifoCompressOut;
       }
 
-      pDevice->pFifoRead        = NULL;
-      pDevice->pFifoHashIn      = NULL;
-      pDevice->pFifoHashOut     = NULL;
-      pDevice->pFifoWrite1      = NULL;
-      pDevice->pFifoWrite2      = NULL;
-      pDevice->pFifoCompressIn  = NULL;
-      pDevice->pFifoCompressOut = NULL;
+      pDevice->pFifoRead        = nullptr;
+      pDevice->pFifoHashIn      = nullptr;
+      pDevice->pFifoHashOut     = nullptr;
+      pDevice->pFifoWrite1      = nullptr;
+      pDevice->pFifoWrite2      = nullptr;
+      pDevice->pFifoCompressIn  = nullptr;
+      pDevice->pFifoCompressOut = nullptr;
 
       if (CONFIG (FifoMemoryManager))
          CHK (FifoMemoryFree (&pDevice->pFifoMemory))
@@ -1210,7 +1213,7 @@ void t_Table::SlotThreadReadFinished (t_pDevice pDevice)
 {
    LOG_INFO ("[%s] Read thread finished", QSTR_TO_PSZ (pDevice->LinuxDevice))
    pDevice->pThreadRead->deleteLater();
-   pDevice->pThreadRead = NULL;
+   pDevice->pThreadRead = nullptr;
 
    if (pDevice->Error.Abort())
         CHK_EXIT (pDevice->WakeWaitingThreads())
@@ -1222,7 +1225,7 @@ void t_Table::SlotThreadHashFinished (t_pDevice pDevice)
 {
    LOG_INFO ("[%s] Hash thread finished", QSTR_TO_PSZ (pDevice->LinuxDevice))
    pDevice->pThreadHash->deleteLater();
-   pDevice->pThreadHash = NULL;
+   pDevice->pThreadHash = nullptr;
 
    if (pDevice->Error.Abort())
         CHK_EXIT (pDevice->WakeWaitingThreads())
@@ -1237,12 +1240,12 @@ void t_Table::SlotThreadCompressFinished (t_pDevice pDevice, int ThreadNr)
    LOG_INFO ("[%s] Compression thread #%d finished", QSTR_TO_PSZ (pDevice->LinuxDevice), ThreadNr)
 
    pDevice->ThreadCompressList[ThreadNr]->deleteLater();
-   pDevice->ThreadCompressList[ThreadNr] = NULL;
+   pDevice->ThreadCompressList[ThreadNr] = nullptr;
 
    for (int i=0;
         (i < pDevice->ThreadCompressList.count()) && NoMoreThreads;
         i++)
-      NoMoreThreads = (pDevice->ThreadCompressList[i] == NULL);
+      NoMoreThreads = (pDevice->ThreadCompressList[i] == nullptr);
 
    if (NoMoreThreads)
    {
@@ -1264,7 +1267,7 @@ APIRET t_Table::ThreadWriteFinished (t_pDevice pDevice, t_pThreadWrite *ppThread
    else LOG_INFO ("[%s] Write thread %d finished", QSTR_TO_PSZ (pDevice->LinuxDevice), (*ppThreadWrite)->Instance())
 
    (*ppThreadWrite)->deleteLater();
-   *ppThreadWrite = NULL;
+   *ppThreadWrite = nullptr;
 
    if (pDevice->Error.Abort())
       CHK_EXIT (pDevice->WakeWaitingThreads())
@@ -1312,7 +1315,7 @@ APIRET t_Table::AbortAcquisition0 (t_pDevice pDevice)
    pDevice->Error.Set (t_Device::t_Error::UserRequest);
 
    if (pOwn->JobQueue.removeOne(pDevice))
-        pDevice->SetState (t_Device::Aborted);  // Acquisitoin was queued, so we only need to change the state
+        pDevice->SetState (t_Device::Aborted);  // Acquisition was queued, so we only need to change the state
    else CHK (pDevice->WakeWaitingThreads ())    // Aquisition already was running if not in queue
 
    return NO_ERROR;
@@ -1344,7 +1347,9 @@ APIRET t_Table::AbortAllAcquisitions (void)
    for (i=0; i<pOwn->pDeviceList->count(); i++)
    {
       pDevice = pOwn->pDeviceList->at(i);
-      if ((pDevice->GetState() == t_Device::Acquire)       ||
+      if ((pDevice->GetState() == t_Device::Launch)        ||
+          (pDevice->GetState() == t_Device::LaunchPaused)  ||
+          (pDevice->GetState() == t_Device::Acquire)       ||
           (pDevice->GetState() == t_Device::AcquirePaused) ||
           (pDevice->GetState() == t_Device::Verify)        ||
           (pDevice->GetState() == t_Device::VerifyPaused))
