@@ -9,7 +9,8 @@
 //  Module:         Thread for reading data.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -89,7 +90,7 @@ t_ThreadRead::~t_ThreadRead (void)
 
 inline bool ThreadReadEOF (t_pDevice pDevice)
 {
-//   LOG_INFO ("EOF check %Ld %Ld", pDevice->CurrentPos, pDevice->Size)
+//   LOG_INFO ("EOF check %lld %lld", pDevice->CurrentPos, pDevice->Size)
    return (pDevice->CurrentReadPos.Get() >= pDevice->Size);
 }
 
@@ -98,7 +99,7 @@ static APIRET ThreadReadCheckDeviceExists (t_pcDevice pDevice, bool &DeviceExist
    FILE *pFileTest;
 
    pFileTest = fopen64 (QSTR_TO_PSZ(pDevice->LinuxDevice), "r");
-   DeviceExists = (pFileTest != NULL);
+   DeviceExists = (pFileTest != nullptr);
    if (DeviceExists)
       (void) fclose (pFileTest);
 
@@ -112,11 +113,18 @@ static APIRET ThreadReadDeviceDisconnected (t_pDevice pDevice, const char* pStrA
       (void) close (pDevice->FileDescSrc);
       pDevice->FileDescSrc = t_Device::FileDescEmpty;
    }
-   if (pDevice->GetState() == t_Device::Acquire)
-        pDevice->SetState (t_Device::AcquirePaused);
-   else pDevice->SetState (t_Device::VerifyPaused );
-   LOG_INFO ("[%s] Device disconnected (%s, %d, %s), switching device state to %s", QSTR_TO_PSZ(pDevice->LinuxDevice), pStrAction, errno, strerror(errno), pDevice->StateStr())
-
+   if (pDevice->GetState() == t_Device::Launch)
+   {
+      LOG_INFO ("[%s] Device disconnected just after acquisition launch (%s, %d, %s)", QSTR_TO_PSZ(pDevice->LinuxDevice), pStrAction, errno, strerror(errno))
+      pDevice->SetState (t_Device::LaunchPaused); // Only switch statem, but do not set error here (will be done in t_MainWindow::SlotScanFinished)
+   }
+   else
+   {
+      if (pDevice->GetState() == t_Device::Acquire)
+           pDevice->SetState (t_Device::AcquirePaused);
+      else pDevice->SetState (t_Device::VerifyPaused );
+      LOG_INFO ("[%s] Device disconnected (%s, %d, %s), switching device state to %s", QSTR_TO_PSZ(pDevice->LinuxDevice), pStrAction, errno, strerror(errno), pDevice->StateStr())
+   }
    return ERROR_THREADREAD_DEVICE_DISCONNECTED;
 }
 
@@ -278,9 +286,9 @@ APIRET t_ThreadRead::ThreadReadBlock (t_pFifoBlock &pFifoBlock)
                      if ( CONFIG(BadSectorLogThreshold) == 0                          ||  // Threshold feature disabled if cfg param is zero
                           (BadSectorCount <= (quint64) CONFIG(BadSectorLogThreshold)) ||
                          ((BadSectorCount %  (quint64) CONFIG(BadSectorLogModulo   )) == 0))
-                        LOG_INFO ("[%s] Read error on sector %Ld, bad data replaced by zero block (%Ld bad sectors up until now)", QSTR_TO_PSZ(pDevice->LinuxDevice), Sector, BadSectorCount)
+                        LOG_INFO ("[%s] Read error on sector %lld, bad data replaced by zero block (%lld bad sectors up until now)", QSTR_TO_PSZ(pDevice->LinuxDevice), Sector, BadSectorCount)
                      if (BadSectorCount == (quint64)CONFIG(BadSectorLogThreshold))
-                        LOG_INFO ("[%s] Bad sector threshold has been reached, only logging every 1000th bad sector from now on.", QSTR_TO_PSZ(pDevice->LinuxDevice), Sector)
+                        LOG_INFO ("[%s] Bad sector threshold has been reached, only logging every 1000th bad sector from now on.", QSTR_TO_PSZ(pDevice->LinuxDevice))
 
                      if (CONFIG(JobMaxBadSectors) &&
                         (CONFIG(LimitJobs) != CONFIG_LIMITJOBS_OFF) &&
@@ -302,11 +310,13 @@ APIRET t_ThreadRead::ThreadReadBlock (t_pFifoBlock &pFifoBlock)
          default:
             CHK (RcRead)
       }
-   } while ((BytesRead < BytesToRead) && (pDevice->GetState() != t_Device::AcquirePaused)
+   } while ((BytesRead < BytesToRead) && (pDevice->GetState() != t_Device::LaunchPaused )
+                                      && (pDevice->GetState() != t_Device::AcquirePaused)
                                       && (pDevice->GetState() != t_Device::VerifyPaused )
                                       && !pDevice->Error.Abort());
 
-   if ((pDevice->GetState() == t_Device::AcquirePaused) ||
+   if ((pDevice->GetState() == t_Device::LaunchPaused ) ||
+       (pDevice->GetState() == t_Device::AcquirePaused) ||
        (pDevice->GetState() == t_Device::VerifyPaused ))
    {
       CHK (t_Fifo::Destroy (pDevice->pFifoMemory, pFifoBlock))
@@ -368,7 +378,6 @@ void t_ThreadRead::run (void)
 //   pDevice->AddBadSector (5);
 //   pDevice->AddBadSector (122);
 
-   pDevice->SetState (t_Device::Acquire);
    for (;;)
    {
       pDevice->CurrentReadPos.Zero();
@@ -408,7 +417,8 @@ void t_ThreadRead::run (void)
                break;
 
             case ERROR_THREADREAD_DEVICE_DISCONNECTED:
-               while (!pDevice->Error.Abort() && ((pDevice->GetState() == t_Device::AcquirePaused) ||
+               while (!pDevice->Error.Abort() && ((pDevice->GetState() == t_Device::LaunchPaused ) ||
+                                                  (pDevice->GetState() == t_Device::AcquirePaused) ||
                                                   (pDevice->GetState() == t_Device::VerifyPaused )) )
                   msleep (THREADREAD_CHECK_CONNECTED_SLEEP);
                break;
@@ -424,7 +434,8 @@ void t_ThreadRead::run (void)
       if (pDevice->Error.Abort())
          break;
 
-      if (pDevice->GetState() == t_Device::Acquire)
+      if ((pDevice->GetState() == t_Device::Acquire) ||
+          (pDevice->GetState() == t_Device::Launch))
            BytesRead     = pDevice->CurrentReadPos.Get();
       else BytesVerified = pDevice->CurrentReadPos.Get();
 
@@ -476,9 +487,9 @@ void t_ThreadRead::run (void)
       }
    }
 
-   LOG_INFO ("[%s] Read thread exits now (%Ld blocks read, %llu bytes)", QSTR_TO_PSZ (pDevice->LinuxDevice), BlocksRead, BytesRead)
+   LOG_INFO ("[%s] Read thread exits now (%lld blocks read, %llu bytes)", QSTR_TO_PSZ (pDevice->LinuxDevice), BlocksRead, BytesRead)
    if (pDevice->Acquisition1.VerifySrc)
-      LOG_INFO ("[%s]   Source verification: %Ld blocks read, %llu bytes)", QSTR_TO_PSZ(pDevice->LinuxDevice), BlocksVerified, BytesVerified)
+      LOG_INFO ("[%s]   Source verification: %lld blocks read, %llu bytes)", QSTR_TO_PSZ(pDevice->LinuxDevice), BlocksVerified, BytesVerified)
    CHK_EXIT (SetDebugMessage ("Exit run function"))
 }
 
