@@ -34,6 +34,7 @@
 #include <errno.h>
 #include <zlib.h>
 #include <fcntl.h>
+#include <sys/utsname.h>
 
 #include <QtCore>
 
@@ -975,6 +976,7 @@ class t_OutputFileAEWF: public t_OutputFile
          QString  FileName;
          QString  GuymagerVersion;
          QString  Uname;
+         struct   utsname SystemVersion;
          APIRET   rc;
 
          poAcquisition = pAcquisition;
@@ -994,7 +996,10 @@ class t_OutputFileAEWF: public t_OutputFile
          }
          else
          {
-            CHK (ToolSysInfoUname (Uname))
+            if (uname (&SystemVersion) == -1)
+               return ERROR_THREADWRITE_OSVERSION_QUERY_FAILED;
+
+            Uname = QString(SystemVersion.release);
             GuymagerVersion = QString("guymager ") + QString(pCompileInfoVersion);
             if (CONFIG (AvoidEncaseProblems))
             {
@@ -1196,6 +1201,7 @@ t_ThreadWrite::t_ThreadWrite (t_pAcquisition pAcquisition, t_pFifo *ppFifo, bool
       CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_THREADWRITE_HANDLE_TIMEOUT           ))
       CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_THREADWRITE_LIBEWF_FAILED            ))
       CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_THREADWRITE_MALLOC_FAILED            ))
+      CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_THREADWRITE_OSVERSION_QUERY_FAILED   ))
    }
 
    pOwn = new t_ThreadWriteLocal;
